@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2017 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019 Aurimas Cernius
  * Copyright (C) 2009, 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -36,7 +36,6 @@
 #include "debug.hpp"
 #include "iactionmanager.hpp"
 #include "ignote.hpp"
-#include "preferences.hpp"
 #include "preferencetabaddin.hpp"
 #include "watchers.hpp"
 #include "notebooks/notebookapplicationaddin.hpp"
@@ -60,7 +59,7 @@ namespace gnote {
 #define SETUP_NOTE_ADDIN(key, KEY, klass) \
   do { \
     if(key == KEY) { \
-      Glib::RefPtr<Gio::Settings> settings = Preferences::obj() \
+      Glib::RefPtr<Gio::Settings> settings = m_preferences \
         .get_schema_settings(Preferences::SCHEMA_GNOTE); \
       if(settings->get_boolean(key)) { \
         sharp::IfaceFactoryBase *iface = new sharp::IfaceFactory<klass>; \
@@ -90,8 +89,10 @@ namespace {
 }
 
 
-  AddinManager::AddinManager(NoteManager & note_manager, const Glib::ustring & conf_dir)
-    : m_note_manager(note_manager)
+  AddinManager::AddinManager(IGnote & g, NoteManager & note_manager, Preferences & preferences, const Glib::ustring & conf_dir)
+    : m_gnote(g)
+    , m_note_manager(note_manager)
+    , m_preferences(preferences)
     , m_gnote_conf_dir(conf_dir)
   {
     m_addins_prefs_dir = Glib::build_filename(conf_dir, "addins");
@@ -116,9 +117,8 @@ namespace {
     }
     sharp::map_delete_all_second(m_addin_prefs);
     sharp::map_delete_all_second(m_import_addins);
-    for(std::list<sharp::IfaceFactoryBase*>::iterator iter = m_builtin_ifaces.begin();
-        iter != m_builtin_ifaces.end(); ++iter) {
-      delete *iter;
+    for(auto iter : m_builtin_ifaces) {
+      delete iter;
     }
   }
 
@@ -159,7 +159,7 @@ namespace {
       const Note::Ptr & note = iter->first;
       NoteAddin *const addin = dynamic_cast<NoteAddin *>((*f)());
       if(addin) {
-       addin->initialize(note);
+       addin->initialize(m_gnote, note);
        id_addin_map.insert(std::make_pair(id, addin));
       }
     }
@@ -206,8 +206,7 @@ namespace {
 
   void AddinManager::load_addin_infos(const Glib::ustring & path)
   {
-    std::list<Glib::ustring> files;
-    sharp::directory_get_files_with_ext(path, ".desktop", files);
+    std::vector<Glib::ustring> files = sharp::directory_get_files_with_ext(path, ".desktop");
     for(auto file : files) {
       try {
         AddinInfo addin_info(file);
@@ -229,8 +228,9 @@ namespace {
     }
   }
 
-  void AddinManager::get_enabled_addins(std::list<Glib::ustring> & addins) const
+  std::vector<Glib::ustring> AddinManager::get_enabled_addins() const
   {
+    std::vector<Glib::ustring> addins;
     bool global_addins_prefs_loaded = true;
     Glib::KeyFile global_addins_prefs;
     try {
@@ -250,6 +250,8 @@ namespace {
           addins.push_back(iter->second.addin_module());
       }
     }
+
+    return addins;
   }
 
   void AddinManager::initialize_sharp_addins()
@@ -257,7 +259,7 @@ namespace {
     if (!sharp::directory_exists (m_addins_prefs_dir))
       g_mkdir_with_parents(m_addins_prefs_dir.c_str(), S_IRWXU);
 
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+    Glib::RefPtr<Gio::Settings> settings = m_preferences
       .get_schema_settings(Preferences::SCHEMA_GNOTE);
     settings->signal_changed()
       .connect(sigc::mem_fun(*this, &AddinManager::on_setting_changed));
@@ -283,8 +285,7 @@ namespace {
     Glib::ustring local_path = m_gnote_conf_dir + "/addins";
 
     load_addin_infos(global_path, local_path);
-    std::list<Glib::ustring> enabled_addins;
-    get_enabled_addins(enabled_addins);
+    std::vector<Glib::ustring> enabled_addins = get_enabled_addins();
     m_module_manager.load_modules(enabled_addins);
 
     const sharp::ModuleMap & modules = m_module_manager.get_modules();
@@ -324,7 +325,6 @@ namespace {
     f = dmod->query_interface(ApplicationAddin::IFACE_NAME);
     if(f) {
       ApplicationAddin * addin = dynamic_cast<ApplicationAddin*>((*f)());
-      addin->note_manager(m_note_manager);
       m_app_addins.insert(std::make_pair(mod_id, addin));
     }
     f = dmod->query_interface(sync::SyncServiceAddin::IFACE_NAME);
@@ -362,7 +362,7 @@ namespace {
       sharp::IInterface* iface = (*addin_info.second)();
       NoteAddin * addin = dynamic_cast<NoteAddin *>(iface);
       if(addin) {
-        addin->initialize(note);
+        addin->initialize(m_gnote, note);
         loaded.insert(std::make_pair(addin_info.first, addin));
       }
       else {
@@ -413,21 +413,21 @@ namespace {
     return NULL;
   }
 
-  void AddinManager::get_preference_tab_addins(std::list<PreferenceTabAddin *> &l) const
+  std::vector<PreferenceTabAddin*> AddinManager::get_preference_tab_addins() const
   {
-    sharp::map_get_values(m_pref_tab_addins, l);
+    return sharp::map_get_values(m_pref_tab_addins);
   }
 
 
-  void AddinManager::get_sync_service_addins(std::list<sync::SyncServiceAddin *> &l) const
+  std::vector<sync::SyncServiceAddin*> AddinManager::get_sync_service_addins() const
   {
-    sharp::map_get_values(m_sync_service_addins, l);
+    return sharp::map_get_values(m_sync_service_addins);
   }
 
 
-  void AddinManager::get_import_addins(std::list<ImportAddin*> & l) const
+  std::vector<ImportAddin*> AddinManager::get_import_addins() const
   {
-    sharp::map_get_values(m_import_addins, l);
+    return sharp::map_get_values(m_import_addins);
   }
 
   void AddinManager::initialize_application_addins() const
@@ -436,11 +436,10 @@ namespace {
     for(AppAddinMap::const_iterator iter = m_app_addins.begin();
         iter != m_app_addins.end(); ++iter) {
       ApplicationAddin * addin = iter->second;
-      addin->note_manager(m_note_manager);
       const sharp::DynamicModule * dmod
         = m_module_manager.get_module(iter->first);
       if (!dmod || dmod->is_enabled()) {
-        addin->initialize();
+        addin->initialize(m_gnote, m_note_manager);
       }
     }
   }
@@ -454,7 +453,7 @@ namespace {
         addin = iter->second;
         const sharp::DynamicModule *dmod = m_module_manager.get_module(iter->first);
         if(!dmod || dmod->is_enabled()) {
-          addin->initialize();
+          addin->initialize(m_gnote, m_gnote.sync_manager());
         }
       }
       catch(std::exception & e) {
@@ -565,7 +564,7 @@ namespace {
   {
     IdAddinPrefsMap::const_iterator iter = m_addin_prefs.find(id);
     if(iter != m_addin_prefs.end()) {
-      return iter->second->create_preference_widget(m_note_manager);
+      return iter->second->create_preference_widget(m_gnote, m_gnote.preferences(), m_note_manager);
     }
     return NULL;
   }
@@ -579,7 +578,7 @@ namespace {
 
   void AddinManager::register_addin_actions() const
   {
-    auto & manager(IActionManager::obj());
+    auto & manager(m_gnote.action_manager());
     for(auto & info : m_addin_infos) {
       auto & non_modifying = info.second.non_modifying_actions();
       for(auto & action : info.second.actions()) {
