@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010,2012-2015,2017 Aurimas Cernius
+ * Copyright (C) 2010,2012-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -23,7 +23,6 @@
 #ifndef __ADDINMANAGER_HPP__
 #define __ADDINMANAGER_HPP__
 
-#include <list>
 #include <map>
 
 #include <sigc++/signal.h>
@@ -33,6 +32,7 @@
 #include "note.hpp"
 #include "noteaddin.hpp"
 #include "importaddin.hpp"
+#include "preferences.hpp"
 
 
 namespace gnote {
@@ -51,8 +51,7 @@ typedef std::map<Glib::ustring, AddinInfo> AddinInfoMap;
 class AddinManager
 {
 public:
-
-  AddinManager(NoteManager & note_manager, const Glib::ustring & conf_dir);
+  AddinManager(IGnote & g, NoteManager & note_manager, Preferences & preferences, const Glib::ustring & conf_dir);
   ~AddinManager();
 
   void add_note_addin_info(const Glib::ustring & id, const sharp::DynamicModule * dmod);
@@ -67,9 +66,9 @@ public:
   std::vector<NoteAddin*> get_note_addins(const Note::Ptr &) const;
   ApplicationAddin *get_application_addin(const Glib::ustring & id) const;
   sync::SyncServiceAddin *get_sync_service_addin(const Glib::ustring & id) const;
-  void get_preference_tab_addins(std::list<PreferenceTabAddin *> &) const;
-  void get_sync_service_addins(std::list<sync::SyncServiceAddin *> &) const;
-  void get_import_addins(std::list<ImportAddin*> &) const;
+  std::vector<PreferenceTabAddin*> get_preference_tab_addins() const;
+  std::vector<sync::SyncServiceAddin*> get_sync_service_addins() const;
+  std::vector<ImportAddin*> get_import_addins() const;
   void initialize_application_addins() const;
   void initialize_sync_service_addins() const;
   void shutdown_application_addins() const;
@@ -89,19 +88,21 @@ private:
   void load_addin_infos(const Glib::ustring & global_path, const Glib::ustring & local_path);
   void load_addin_infos(const Glib::ustring & path);
   void load_note_addin(const Glib::ustring & id, sharp::IfaceFactoryBase *const f);
-  void get_enabled_addins(std::list<Glib::ustring> & addins) const;
+  std::vector<Glib::ustring> get_enabled_addins() const;
   void initialize_sharp_addins();
   void add_module_addins(const Glib::ustring & mod_id, sharp::DynamicModule * dmod);
   AddinInfo get_info_for_module(const Glib::ustring & module) const;
   void on_setting_changed(const Glib::ustring & key);
   void register_addin_actions() const;
     
+  IGnote & m_gnote;
   NoteManager & m_note_manager;
+  Preferences & m_preferences;
   const Glib::ustring m_gnote_conf_dir;
   Glib::ustring m_addins_prefs_dir;
   Glib::ustring m_addins_prefs_file;
   sharp::ModuleManager m_module_manager;
-  std::list<sharp::IfaceFactoryBase*> m_builtin_ifaces;
+  std::vector<sharp::IfaceFactoryBase*> m_builtin_ifaces;
   AddinInfoMap m_addin_infos;
   /// Key = TypeExtensionNode.Id
   typedef std::map<Glib::ustring, ApplicationAddin*> AppAddinMap;
