@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2013,2016-2017 Aurimas Cernius
+ * Copyright (C) 2010-2013,2016-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@
 #include "sharp/xsltargumentlist.hpp"
 #include "debug.hpp"
 #include "iactionmanager.hpp"
+#include "ignote.hpp"
 #include "preferences.hpp"
 #include "notewindow.hpp"
 #include "utils.hpp"
@@ -75,18 +76,18 @@ void ExportToHtmlNoteAddin::on_note_opened()
 }
 
 
-std::map<int, Gtk::Widget*> ExportToHtmlNoteAddin::get_actions_popover_widgets() const
+std::vector<gnote::PopoverWidget> ExportToHtmlNoteAddin::get_actions_popover_widgets() const
 {
   auto widgets = NoteAddin::get_actions_popover_widgets();
   auto button = gnote::utils::create_popover_button("win.exporttohtml-export", _("Export to HTML…"));
-  gnote::utils::add_item_to_ordered_map(widgets, gnote::EXPORT_TO_HTML_ORDER, button);
+  widgets.push_back(gnote::PopoverWidget::create_for_note(gnote::EXPORT_TO_HTML_ORDER, button));
   return widgets;
 }
 
 
 void ExportToHtmlNoteAddin::export_button_clicked(const Glib::VariantBase&)
 {
-  ExportToHtmlDialog dialog(get_note()->get_title() + ".html");
+  ExportToHtmlDialog dialog(ignote(), get_note()->get_title() + ".html");
   int response = dialog.run();
   Glib::ustring output_path = dialog.get_filename();
 
@@ -225,7 +226,7 @@ void ExportToHtmlNoteAddin::write_html_for_note (sharp::StreamWriter & writer,
                                                  bool export_linked_all)
 {
   Glib::ustring s_writer;
-  s_writer = gnote::NoteArchiver::write_string(note->data());
+  s_writer = note->manager().note_archiver().write_string(note->data());
   xmlDocPtr doc = xmlParseMemory(s_writer.c_str(), s_writer.bytes());
 
   sharp::XsltArgumentList args;
@@ -233,7 +234,7 @@ void ExportToHtmlNoteAddin::write_html_for_note (sharp::StreamWriter & writer,
   args.add_param ("export-linked-all", "", export_linked_all);
   args.add_param ("root-note", "", gnote::utils::XmlEncoder::encode(note->get_title()));
 
-  Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+  Glib::RefPtr<Gio::Settings> settings = ignote().preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
   if (settings->get_boolean(Preferences::ENABLE_CUSTOM_FONT)) {
     Glib::ustring font_face = settings->get_string(Preferences::CUSTOM_FONT_FACE);
     Pango::FontDescription font_desc (font_face);
