@@ -52,7 +52,7 @@ public:
   virtual void initialize() override;
   virtual void shutdown() override;
 
-  virtual gnote::sync::SyncServer::Ptr create_sync_server() override;
+  virtual gnote::sync::SyncServer *create_sync_server() override;
   virtual void post_sync_cleanup() override;
   virtual Gtk::Widget *create_preferences_control(EventHandler requiredPrefChanged) override;
   virtual bool save_configuration(const sigc::slot<void, bool, Glib::ustring> & on_saved) override;
