@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010,2013,2016-2017 Aurimas Cernius
+ * Copyright (C) 2010,2013,2016-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -52,7 +52,7 @@ public:
   virtual void initialize() override;
   virtual void shutdown() override;
   virtual void on_note_opened() override;
-  virtual std::map<int, Gtk::Widget*> get_actions_popover_widgets() const override;
+  virtual std::vector<gnote::PopoverWidget> get_actions_popover_widgets() const override;
 private:
   void on_menu_item_activated(const Glib::VariantBase&);
   void on_format_setting_changed(const Glib::ustring & key);
