@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2013-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009-2010 Debarshi Ray
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 #include "debug.hpp"
 #include "notemanager.hpp"
 #include "noteoftheday.hpp"
-#include "itagmanager.hpp"
 #include "utils.hpp"
 
 namespace noteoftheday {
@@ -54,8 +53,7 @@ gnote::NoteBase::Ptr NoteOfTheDay::create(gnote::NoteManager & manager,
   }
 
   // Automatically tag all new Note of the Day notes
-  notd->add_tag(gnote::ITagManager::obj().get_or_create_system_tag(
-                                           "NoteOfTheDay"));
+  notd->add_tag(manager.tag_manager().get_or_create_system_tag("NoteOfTheDay"));
 
   return notd;
 }
@@ -68,22 +66,22 @@ void NoteOfTheDay::cleanup_old(gnote::NoteManager & manager)
   Glib::Date date;
   date.set_time_current(); // time set to 00:00:00
 
-  FOREACH(const gnote::NoteBase::Ptr & note, notes) {
+  for(const gnote::NoteBase::Ptr & note : notes) {
     const Glib::ustring & title = note->get_title();
-    const sharp::DateTime & date_time = note->create_date();
+    const auto & date_time = note->create_date();
 
     if (true == Glib::str_has_prefix(title, s_title_prefix)
         && s_template_title != title
         && Glib::Date(
-             date_time.day(),
-             static_cast<Glib::Date::Month>(date_time.month()),
-             date_time.year()) != date
+             date_time.get_day_of_month(),
+             static_cast<Glib::Date::Month>(date_time.get_month()),
+             date_time.get_year()) != date
         && !has_changed(note)) {
       kill_list.push_back(note);
     }
   }
 
-  FOREACH(gnote::NoteBase::Ptr & note, kill_list) {
+  for(gnote::NoteBase::Ptr & note : kill_list) {
     DBG_OUT("NoteOfTheDay: Deleting old unmodified '%s'", note->get_title().c_str());
     manager.delete_note(note);
   }
@@ -123,16 +121,16 @@ gnote::NoteBase::Ptr NoteOfTheDay::get_note_by_date(
 {
   const gnote::NoteBase::List & notes = manager.get_notes();
 
-  FOREACH(gnote::NoteBase::Ptr note, notes) {
+  for(gnote::NoteBase::Ptr note : notes) {
     const Glib::ustring & title = note->get_title();
-    const sharp::DateTime & date_time = note->create_date();
+    const auto & date_time = note->create_date();
 
     if (true == Glib::str_has_prefix(title, s_title_prefix)
         && s_template_title != title
         && Glib::Date(
-             date_time.day(),
-             static_cast<Glib::Date::Month>(date_time.month()),
-             date_time.year()) == date) {
+             date_time.get_day_of_month(),
+             static_cast<Glib::Date::Month>(date_time.get_month()),
+             date_time.get_year()) == date) {
       return note;
     }
   }
@@ -161,15 +159,15 @@ Glib::ustring NoteOfTheDay::get_title(const Glib::Date & date)
 
 bool NoteOfTheDay::has_changed(const gnote::NoteBase::Ptr & note)
 {
-  const sharp::DateTime & date_time = note->create_date();
+  const auto & date_time = note->create_date();
   const Glib::ustring original_xml
     = get_content(Glib::Date(
-                    date_time.day(),
-                    static_cast<Glib::Date::Month>(date_time.month()),
-                    date_time.year()),
+                    date_time.get_day_of_month(),
+                    static_cast<Glib::Date::Month>(date_time.get_month()),
+                    date_time.get_year()),
                     *static_cast<gnote::NoteManager*>(&note->manager()));
 
-  return get_content_without_title(static_pointer_cast<gnote::Note>(note)->text_content())
+  return get_content_without_title(std::static_pointer_cast<gnote::Note>(note)->text_content())
            == get_content_without_title(
                 gnote::utils::XmlDecoder::decode(original_xml))
          ? false
