@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2013,2015-2017 Aurimas Cernius
+ * Copyright (C) 2010-2013,2015-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -25,7 +25,6 @@
 #include <gtkmm/image.h>
 #include <gtkmm/printoperation.h>
 
-#include "sharp/datetime.hpp"
 #include "debug.hpp"
 #include "iactionmanager.hpp"
 #include "notetag.hpp"
@@ -57,11 +56,11 @@ namespace printnotes {
   }
 
 
-  std::map<int, Gtk::Widget*> PrintNotesNoteAddin::get_actions_popover_widgets() const
+  std::vector<gnote::PopoverWidget> PrintNotesNoteAddin::get_actions_popover_widgets() const
   {
     auto widgets = NoteAddin::get_actions_popover_widgets();
     auto button = gnote::utils::create_popover_button("win.printnotes-print", _("Print…"));
-    gnote::utils::add_item_to_ordered_map(widgets, gnote::PRINT_ORDER, button);
+    widgets.push_back(gnote::PopoverWidget::create_for_note(gnote::PRINT_ORDER, button));
     return widgets;
   }
 
@@ -116,14 +115,13 @@ namespace printnotes {
   }
 
 
-  void PrintNotesNoteAddin::get_paragraph_attributes(const Glib::RefPtr<Pango::Layout> & layout,
+  std::vector<Pango::Attribute> PrintNotesNoteAddin::get_paragraph_attributes(const Glib::RefPtr<Pango::Layout> & layout,
                                                      double dpiX, 
                                                      int & indentation,
                                                      Gtk::TextIter & position, 
-                                                     const Gtk::TextIter & limit,
-                                                     std::list<Pango::Attribute> & attributes)
+                                                     const Gtk::TextIter & limit)
   {
-    attributes.clear();
+    std::vector<Pango::Attribute> attributes;
     indentation = 0;
 
     Glib::SListHandle<Glib::RefPtr<Gtk::TextTag> > tags = position.get_tags();
@@ -206,6 +204,8 @@ namespace printnotes {
                                tag->property_stretch()));
       }
     }
+
+    return attributes;
   }
 
   Glib::RefPtr<Pango::Layout> 
@@ -230,17 +230,12 @@ namespace printnotes {
 
       while (segm_start.compare (p_end) < 0) {
         segm_end = segm_start;
-        std::list<Pango::Attribute> attrs;
-        get_paragraph_attributes (layout, dpiX, indentation,
-                                  segm_end, p_end, attrs);
+        auto attrs = get_paragraph_attributes(layout, dpiX, indentation, segm_end, p_end);
 
         guint si = (guint) (segm_start.get_line_index() - start_index);
         guint ei = (guint) (segm_end.get_line_index() - start_index);
 
-        for(std::list<Pango::Attribute>::iterator iter = attrs.begin();
-            iter != attrs.end(); ++iter) {
-          
-          Pango::Attribute & a(*iter);
+        for(auto & a : attrs) {
           a.set_start_index(si);
           a.set_end_index(ei);
           attr_list.insert(a);
@@ -287,7 +282,7 @@ namespace printnotes {
   Glib::RefPtr<Pango::Layout> 
   PrintNotesNoteAddin::create_layout_for_timestamp(const Glib::RefPtr<Gtk::PrintContext> & context)
   {
-    Glib::ustring timestamp = sharp::DateTime::now().to_string("%c");
+    Glib::ustring timestamp = sharp::date_time_to_string(Glib::DateTime::create_now_local(), "%c");
 
     Glib::RefPtr<Pango::Layout> layout = context->create_pango_layout ();
     Pango::FontDescription font_desc = get_window()->editor()->get_pango_context()->get_font_description();
