@@ -3,7 +3,7 @@
  *  It lists note's table of contents in a menu.
  *
  * Copyright (C) 2013 Luc Pionchon <pionchon.luc@gmail.com>
- * Copyright (C) 2013,2017 Aurimas Cernius
+ * Copyright (C) 2013,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -26,22 +26,22 @@
 
 #include <gtkmm/imagemenuitem.h>
 
-#include "base/macros.hpp"
 #include "note.hpp"
 #include "tableofcontents.hpp"
 
 
+namespace gnote {
+  class IconManager;
+}
+
 namespace tableofcontents {
 
 
 class TableofcontentsMenuItem : public Gtk::ImageMenuItem
 {
 public:
-  TableofcontentsMenuItem ( const gnote::Note::Ptr & note,
-                           const Glib::ustring     & heading,
-                           Heading::Type            heading_level,
-                           int                      heading_position
-                         );
+  TableofcontentsMenuItem(gnote::IconManager & icon_manager, const gnote::Note::Ptr & note,
+                          const Glib::ustring & heading, Heading::Type heading_level, int heading_position);
 
 protected:
   virtual void on_activate() override;
