@@ -3,7 +3,7 @@
  *  It lists note's table of contents in a menu.
  *
  * Copyright (C) 2013 Luc Pionchon <pionchon.luc@gmail.com>
- * Copyright (C) 2013,2015-2017 Aurimas Cernius <aurisc4@gmail.com>
+ * Copyright (C) 2013,2015-2017,2019 Aurimas Cernius <aurisc4@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,7 @@
 #include "sharp/string.hpp"
 
 #include "iactionmanager.hpp"
+#include "ignote.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "notebuffer.hpp"
@@ -124,13 +125,13 @@ void TableofcontentsNoteAddin::on_foregrounded()
 }
 
 
-std::map<int, Gtk::Widget*> TableofcontentsNoteAddin::get_actions_popover_widgets() const
+std::vector<gnote::PopoverWidget> TableofcontentsNoteAddin::get_actions_popover_widgets() const
 {
   auto widgets = NoteAddin::get_actions_popover_widgets();
   auto toc_item = gnote::utils::create_popover_submenu_button("tableofcontents-menu", _("Table of Contents"));
-  gnote::utils::add_item_to_ordered_map(widgets, gnote::TABLE_OF_CONTENTS_ORDER, toc_item);
+  widgets.push_back(gnote::PopoverWidget(gnote::NOTE_SECTION_CUSTOM_SECTIONS, gnote::TABLE_OF_CONTENTS_ORDER, toc_item));
   auto toc_menu = gnote::utils::create_popover_submenu("tableofcontents-menu");
-  gnote::utils::add_item_to_ordered_map(widgets, 100000, toc_menu);
+  widgets.push_back(gnote::PopoverWidget::create_custom_section(toc_menu));
 
   std::vector<Gtk::Widget*> toc_items;
   get_toc_popover_items(toc_items);
@@ -179,12 +180,9 @@ void TableofcontentsNoteAddin::populate_toc_menu (Gtk::Menu *toc_menu, bool has_
   }
 
   // Build a new list
-  std::list<TableofcontentsMenuItem*> items;
-  get_tableofcontents_menu_items(items);
+  auto items = get_tableofcontents_menu_items();
 
-  for(std::list<TableofcontentsMenuItem*>::iterator iter = items.begin();
-      iter != items.end(); ++iter) {
-    TableofcontentsMenuItem *item(*iter);
+  for(auto item : items) {
     item->show_all();
     toc_menu->append(*item);
   }
@@ -306,10 +304,11 @@ void TableofcontentsNoteAddin::get_toc_items(std::vector<TocItem> & items) const
 }
 
 
-void TableofcontentsNoteAddin::get_tableofcontents_menu_items(std::list<TableofcontentsMenuItem*> & items)
+std::vector<TableofcontentsMenuItem*> TableofcontentsNoteAddin::get_tableofcontents_menu_items()
 //go through the note text, and list all lines tagged as heading,
 //and for each heading, create a new TableofcontentsMenuItem.
 {
+  std::vector<TableofcontentsMenuItem*> items;
   TableofcontentsMenuItem *item = NULL;
   std::vector<TocItem> toc_items;
 
@@ -317,14 +316,16 @@ void TableofcontentsNoteAddin::get_tableofcontents_menu_items(std::list<Tableofc
   if(toc_items.size()) {
     //If we have at least one heading
     //we also insert an entry linked to the Note's title:
-    item = manage(new TableofcontentsMenuItem(get_note(), get_note()->get_title(), Heading::Title, 0));
+    item = manage(new TableofcontentsMenuItem(ignote().icon_manager(), get_note(), get_note()->get_title(), Heading::Title, 0));
     items.push_back(item);
   }
 
   for(auto & toc_item : toc_items) {
-    item = manage(new TableofcontentsMenuItem(get_note(), toc_item.heading, toc_item.heading_level, toc_item.heading_position));
+    item = manage(new TableofcontentsMenuItem(ignote().icon_manager(), get_note(), toc_item.heading, toc_item.heading_level, toc_item.heading_position));
     items.push_back(item);
   }
+
+  return items;
 }
 
 
