@@ -3,7 +3,7 @@
  *  It lists note's table of contents in a menu.
  *
  * Copyright (C) 2013 Luc Pionchon <pionchon.luc@gmail.com>
- * Copyright (C) 2013,2015-2016 Aurimas Cernius <aurisc4@gmail.com>
+ * Copyright (C) 2013,2015-2016,2019 Aurimas Cernius <aurisc4@gmail.com>
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,12 +24,9 @@
 #ifndef __TABLEOFCONTENT_NOTEADDIN_HPP_
 #define __TABLEOFCONTENT_NOTEADDIN_HPP_
 
-#include <list>
-
 #include <gtkmm/imagemenuitem.h>
 #include <gtkmm/menu.h>
 
-#include "base/macros.hpp"
 #include "sharp/dynamicmodule.hpp"
 #include "note.hpp"
 #include "noteaddin.hpp"
@@ -61,7 +58,7 @@ public:
   virtual void initialize() override;
   virtual void shutdown() override;
   virtual void on_note_opened() override;
-  virtual std::map<int, Gtk::Widget*> get_actions_popover_widgets() const override;
+  virtual std::vector<gnote::PopoverWidget> get_actions_popover_widgets() const override;
 
 private:
   void on_menu_hidden();
@@ -91,7 +88,7 @@ private:
     int            heading_position;
   };
   void get_toc_items(std::vector<TocItem> & items) const;
-  void get_tableofcontents_menu_items (std::list<TableofcontentsMenuItem*> & items);
+  std::vector<TableofcontentsMenuItem*> get_tableofcontents_menu_items();
   void get_toc_popover_items(std::vector<Gtk::Widget*> & items) const;
 
   void headification_switch (Heading::Type heading_request);
