@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2016-2017 Aurimas Cernius
+ * Copyright (C) 2011-2014,2016-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -36,10 +36,11 @@
 namespace gnote {
 
 
-  RemoteControl::RemoteControl(const Glib::RefPtr<Gio::DBus::Connection> & cnx, NoteManager& manager,
+  RemoteControl::RemoteControl(const Glib::RefPtr<Gio::DBus::Connection> & cnx, IGnote & g, NoteManagerBase & manager,
                                const char * path, const char * interface_name,
                                const Glib::RefPtr<Gio::DBus::InterfaceInfo> & gnote_interface)
     : IRemoteControl(cnx, path, interface_name, gnote_interface)
+    , m_gnote(g)
     , m_manager(manager)
   {
     DBG_OUT("initialized remote control");
@@ -62,7 +63,7 @@ namespace gnote {
     if (!note) {
       return false;
     }
-    Tag::Ptr tag = ITagManager::obj().get_or_create_tag(tag_name);
+    Tag::Ptr tag = m_manager.tag_manager().get_or_create_tag(tag_name);
     note->add_tag (tag);
     return true;
   }
@@ -137,13 +138,13 @@ namespace gnote {
 
   void RemoteControl::DisplaySearch()
   {
-    IGnote::obj().open_search_all().present();
+    m_gnote.open_search_all().present();
   }
 
 
   void RemoteControl::DisplaySearchWithText(const Glib::ustring& search_text)
   {
-    MainWindow & recent_changes = IGnote::obj().get_main_window();
+    MainWindow & recent_changes = m_gnote.get_main_window();
     recent_changes.set_search_text(search_text);
     recent_changes.present();
     recent_changes.show_search_bar();
@@ -166,14 +167,13 @@ namespace gnote {
 
   std::vector<Glib::ustring> RemoteControl::GetAllNotesWithTag(const Glib::ustring& tag_name)
   {
-    Tag::Ptr tag = ITagManager::obj().get_tag(tag_name);
+    Tag::Ptr tag = m_manager.tag_manager().get_tag(tag_name);
     if (!tag)
       return std::vector<Glib::ustring>();
 
     std::vector<Glib::ustring> tagged_note_uris;
-    std::list<NoteBase*> notes;
-    tag->get_notes(notes);
-    FOREACH(NoteBase *iter, notes) {
+    auto notes = tag->get_notes();
+    for(NoteBase *iter : notes) {
       tagged_note_uris.push_back(iter->uri());
     }
     return tagged_note_uris;
@@ -181,11 +181,17 @@ namespace gnote {
 
 
   int32_t RemoteControl::GetNoteChangeDate(const Glib::ustring& uri)
+  {
+    return GetNoteChangeDateUnix(uri);
+  }
+
+
+  int64_t RemoteControl::GetNoteChangeDateUnix(const Glib::ustring& uri)
   {
     NoteBase::Ptr note = m_manager.find_by_uri(uri);
     if (!note)
       return -1;
-    return note->metadata_change_date().sec();
+    return note->metadata_change_date().to_unix();
   }
 
 
@@ -204,7 +210,7 @@ namespace gnote {
     NoteBase::Ptr note = m_manager.find_by_uri(uri);
     if (!note)
       return "";
-    return static_pointer_cast<Note>(note)->text_content();
+    return std::static_pointer_cast<Note>(note)->text_content();
   }
 
 
@@ -218,11 +224,17 @@ namespace gnote {
 
 
   int32_t RemoteControl::GetNoteCreateDate(const Glib::ustring& uri)
+  {
+    return GetNoteCreateDateUnix(uri);
+  }
+
+
+  int64_t RemoteControl::GetNoteCreateDateUnix(const Glib::ustring& uri)
   {
     NoteBase::Ptr note = m_manager.find_by_uri(uri);
     if (!note)
       return -1;
-    return note->create_date().sec();
+    return note->create_date().to_unix();
   }
 
 
@@ -242,11 +254,9 @@ namespace gnote {
       return std::vector<Glib::ustring>();
 
     std::vector<Glib::ustring> tags;
-    std::list<Tag::Ptr> l;
-    note->get_tags(l);
-    for (std::list<Tag::Ptr>::const_iterator iter = l.begin();
-         iter != l.end(); ++iter) {
-      tags.push_back((*iter)->normalized_name());
+    std::vector<Tag::Ptr> l = note->get_tags();
+    for(auto & tag : l) {
+      tags.push_back(tag->normalized_name());
     }
     return tags;
   }
@@ -258,7 +268,7 @@ bool RemoteControl::HideNote(const Glib::ustring& uri)
   if (!note)
     return false;
 
-  NoteWindow *window = static_pointer_cast<Note>(note)->get_window();
+  NoteWindow *window = std::static_pointer_cast<Note>(note)->get_window();
   if(window == NULL) {
     return true;
   }
@@ -293,7 +303,7 @@ bool RemoteControl::RemoveTagFromNote(const Glib::ustring& uri,
   NoteBase::Ptr note = m_manager.find_by_uri(uri);
   if (!note)
     return false;
-  Tag::Ptr tag = ITagManager::obj().get_tag(tag_name);
+  Tag::Ptr tag = m_manager.tag_manager().get_tag(tag_name);
   if (tag) {
     note->remove_tag (tag);
   }
@@ -343,7 +353,7 @@ bool RemoteControl::SetNoteContents(const Glib::ustring& uri,
     return false;
   }
 
-  static_pointer_cast<Note>(note)->set_text_content(text_contents);
+  std::static_pointer_cast<Note>(note)->set_text_content(text_contents);
   return true;
 }
 
@@ -393,7 +403,7 @@ void RemoteControl::on_note_saved(const NoteBase::Ptr & note)
 
 MainWindow & RemoteControl::present_note(const NoteBase::Ptr & note)
 {
-  return *MainWindow::present_default(static_pointer_cast<Note>(note));
+  return *MainWindow::present_default(m_gnote, std::static_pointer_cast<Note>(note));
 }
 
 
