@@ -37,11 +37,9 @@
 #include <gtkmm/shortcutswindow.h>
 
 #include "gnote.hpp"
-#include "actionmanager.hpp"
 #include "addinmanager.hpp"
 #include "applicationaddin.hpp"
 #include "debug.hpp"
-#include "iconmanager.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "preferencesdialog.hpp"
@@ -54,7 +52,6 @@
 #include "sharp/streamreader.hpp"
 #include "sharp/files.hpp"
 #include "notebooks/notebookmanager.hpp"
-#include "synchronization/syncmanager.hpp"
 
 
 namespace gnote {
@@ -62,9 +59,12 @@ namespace gnote {
   Gnote::Gnote()
     : Gtk::Application("org.gnome.Gnote", Gio::APPLICATION_HANDLES_COMMAND_LINE)
     , m_manager(NULL)
+    , m_sync_manager(NULL)
     , m_is_background(false)
     , m_is_shell_search(false)
+    , m_remote_control(*this)
     , m_prefsdlg(NULL)
+    , m_cmd_line(*this)
   {
   }
 
@@ -73,6 +73,9 @@ namespace gnote {
     if (m_prefsdlg) {
       delete m_prefsdlg;
     }
+    if(m_sync_manager) {
+      delete m_sync_manager;
+    }
     delete m_manager;
   }
 
@@ -88,8 +91,8 @@ namespace gnote {
     }
 
     if(handle) {
-      cmd_line.parse(argc, argv);
-      cmd_line.immediate_execute();
+      m_cmd_line.parse(argc, argv);
+      m_cmd_line.immediate_execute();
       return 0;
     }
 
@@ -113,20 +116,23 @@ namespace gnote {
     Gtk::Application::on_command_line(command_line);
     int argc = 0;
     char **argv = command_line->get_arguments(argc);
-    GnoteCommandLine passed_cmd_line;
-    GnoteCommandLine &cmdline = m_manager ? passed_cmd_line : cmd_line;
+    GnoteCommandLine passed_cmd_line(*this);
+    GnoteCommandLine &cmdline = m_manager ? passed_cmd_line : m_cmd_line;
     cmdline.parse(argc, argv);
     m_is_background = cmdline.background();
-    m_is_shell_search = cmd_line.shell_search();
+    m_is_shell_search = m_cmd_line.shell_search();
     if(!m_manager) {
       common_init();
       register_object();
     }
-    else if(cmdline.needs_execute()) {
-      cmdline.execute();
-    }
-    else if(!(cmdline.background() || cmdline.shell_search())) {
-      new_main_window().present();
+    else {
+      cmdline.set_note_manager(*m_manager);
+      if(cmdline.needs_execute()) {
+        cmdline.execute();
+      }
+      else if(!(cmdline.background() || cmdline.shell_search())) {
+        new_main_window().present();
+      }
     }
 
     g_strfreev(argv);
@@ -136,15 +142,15 @@ namespace gnote {
 
   void Gnote::common_init()
   {
-    Glib::ustring note_path = get_note_path(cmd_line.note_path());
+    Glib::ustring note_path = get_note_path(m_cmd_line.note_path());
 
     //create singleton objects
-    new TagManager;
-    new Preferences;
-    m_manager = new NoteManager(note_path);
-    new notebooks::NotebookManager(default_note_manager());
-    new ActionManager;
-    sync::SyncManager::init(default_note_manager());
+    m_preferences.init();
+    m_manager = new NoteManager(*this);
+    m_manager->init(note_path);
+    m_action_manager.init();
+    m_sync_manager = new sync::SyncManager(*this, default_note_manager());
+    m_sync_manager->init();
 
     m_manager->get_addin_manager().initialize_application_addins();
   }
@@ -152,8 +158,9 @@ namespace gnote {
 
   void Gnote::end_main(bool bus_acquired, bool name_acquired)
   {
-    if(cmd_line.needs_execute()) {
-      cmd_line.execute();
+    m_cmd_line.set_note_manager(*m_manager);
+    if(m_cmd_line.needs_execute()) {
+      m_cmd_line.execute();
     }
 
     if(bus_acquired) {
@@ -167,7 +174,7 @@ namespace gnote {
         if(!m_is_background) {
           Glib::RefPtr<RemoteControlClient> remote;
           try {
-            remote = RemoteControlProxy::get_instance();
+            remote = m_remote_control.get_instance();
             DBG_ASSERT(remote, "remote is NULL, something is wrong");
             if(remote) {
               remote->DisplaySearch();
@@ -217,15 +224,13 @@ namespace gnote {
 
   void Gnote::register_remote_control(NoteManager & manager, RemoteControlProxy::slot_name_acquire_finish on_finish)
   {
-    RemoteControlProxy::register_remote(manager, on_finish);
+    m_remote_control.register_remote(manager, on_finish);
   }
 
 
   void Gnote::register_object()
   {
-    RemoteControlProxy::register_object(Gio::DBus::Connection::get_sync(Gio::DBus::BUS_TYPE_SESSION),
-                                        default_note_manager(),
-                                        sigc::mem_fun(*this, &Gnote::end_main));
+    m_remote_control.register_object(Gio::DBus::Connection::get_sync(Gio::DBus::BUS_TYPE_SESSION), default_note_manager(), sigc::mem_fun(*this, &Gnote::end_main));
   }
 
 
@@ -239,7 +244,7 @@ namespace gnote {
   void Gnote::on_show_preferences_action(const Glib::VariantBase&)
   {
     if(!m_prefsdlg) {
-      m_prefsdlg = new PreferencesDialog(default_note_manager());
+      m_prefsdlg = new PreferencesDialog(*this, default_note_manager());
       m_prefsdlg->signal_response().connect(
         sigc::mem_fun(*this, &Gnote::on_preferences_response));
     }
@@ -285,7 +290,7 @@ namespace gnote {
     about.set_name("Gnote");
     about.set_program_name("Gnote");
     about.set_version(VERSION);
-    about.set_logo(IconManager::obj().get_icon(IconManager::GNOTE, 48));
+    about.set_logo(m_icon_manager.get_icon(IconManager::GNOTE, 48));
     about.set_copyright(_("Copyright \xc2\xa9 2010-2020 Aurimas Cernius\n"
                           "Copyright \xc2\xa9 2009-2011 Debarshi Ray\n"
                           "Copyright \xc2\xa9 2009 Hubert Figuiere\n"
@@ -316,7 +321,7 @@ namespace gnote {
 
   MainWindow & Gnote::new_main_window()
   {
-    NoteRecentChanges *win = new NoteRecentChanges(default_note_manager());
+    NoteRecentChanges *win = new NoteRecentChanges(*this, default_note_manager());
     win->signal_hide().connect([this, win]() { on_main_window_closed(win); });
     add_window(*win);
     return *win;
@@ -396,8 +401,7 @@ namespace gnote {
     // if notes are opened in new window by default, then open new window for search
     // otherwise switch the only window to search
     // if there is more than one window open, open new for search, since we can't decide which one to switch
-    bool new_window = Preferences::obj()
-      .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
+    bool new_window = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(Preferences::OPEN_NOTES_IN_NEW_WINDOW);
     if(main_windows > 1 || new_window) {
       MainWindow & main_window = new_main_window();
       main_window.present_search();
@@ -411,7 +415,7 @@ namespace gnote {
   void Gnote::open_note_sync_window(const Glib::VariantBase&)
   {
     if(m_sync_dlg == 0) {
-      m_sync_dlg = sync::SyncDialog::create(default_note_manager());
+      m_sync_dlg = sync::SyncDialog::create(*this, default_note_manager());
       m_sync_dlg->signal_response().connect(sigc::mem_fun(*this, &Gnote::on_sync_dialog_response));
     }
 
@@ -428,17 +432,16 @@ namespace gnote {
 
   void Gnote::make_app_actions()
   {
-    IActionManager & am(IActionManager::obj());
-    am.get_app_action("new-note")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_new_note_app_action));
-    am.get_app_action("new-window")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_new_window_action));
-    am.get_app_action("show-preferences")->signal_activate().connect(
+    m_action_manager.get_app_action("new-note")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_new_note_app_action));
+    m_action_manager.get_app_action("new-window")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_new_window_action));
+    m_action_manager.get_app_action("show-preferences")->signal_activate().connect(
       sigc::mem_fun(*this, &Gnote::on_show_preferences_action));
-    am.get_app_action("sync-notes")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::open_note_sync_window));
-    am.get_app_action("help-contents")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_action));
-    am.get_app_action("help-shortcuts")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_shortcust_action));
-    am.get_app_action("about")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_about_action));
+    m_action_manager.get_app_action("sync-notes")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::open_note_sync_window));
+    m_action_manager.get_app_action("help-contents")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_action));
+    m_action_manager.get_app_action("help-shortcuts")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_help_shortcust_action));
+    m_action_manager.get_app_action("about")->signal_activate().connect(sigc::mem_fun(*this, &Gnote::on_show_about_action));
 
-    add_app_actions(static_cast<ActionManager &>(am).get_app_actions());
+    add_app_actions(m_action_manager.get_app_actions());
   }
 
 
@@ -489,9 +492,16 @@ namespace gnote {
     MainWindow::present_in(get_window_for_note(), note);
   }
 
+  notebooks::NotebookManager & Gnote::notebook_manager()
+  {
+    return m_manager->notebook_manager();
+  }
 
-  GnoteCommandLine::GnoteCommandLine()
+
+  GnoteCommandLine::GnoteCommandLine(IGnote & ignote)
     : m_context(g_option_context_new("Foobar"))
+    , m_gnote(ignote)
+    , m_manager(NULL)
     , m_use_panel(false)
     , m_background(false)
     , m_shell_search(false)
@@ -586,20 +596,20 @@ namespace gnote {
   {
     DBG_OUT("running args");
 
-    RemoteControl *remote_control = RemoteControlProxy::get_remote_control();
+    RemoteControl *remote_control = static_cast<Gnote&>(m_gnote).remote_control().get_remote_control();
     if(remote_control) {
       execute(remote_control);
     }
     else {
       //gnote already running, execute via D-Bus and exit this instance
-      Glib::RefPtr<RemoteControlClient> remote = RemoteControlProxy::get_instance();
+      Glib::RefPtr<RemoteControlClient> remote = static_cast<Gnote&>(m_gnote).remote_control().get_instance();
       if(!remote) {
         ERR_OUT(_("Could not connect to remote instance."));
       }
       else {
         execute(remote);
       }
-      static_cast<Gnote&>(Gnote::obj()).quit();
+      static_cast<Gnote&>(m_gnote).quit();
     }
     return 0;
   }
@@ -671,7 +681,7 @@ namespace gnote {
             }
 
             if (!noteXml.empty()) {
-              noteTitle = NoteArchiver::obj().get_title_from_note_xml (noteXml);
+              noteTitle = m_manager->note_archiver().get_title_from_note_xml (noteXml);
               if (!noteTitle.empty()) {
                 // Check for conflicting titles
                 Glib::ustring baseTitle = noteTitle;
@@ -682,7 +692,7 @@ namespace gnote {
                 Glib::ustring note_uri = remote->CreateNamedNote(noteTitle);
 
                 // Update title in the note XML
-                noteXml = NoteArchiver::obj().get_renamed_note_xml (noteXml, baseTitle, noteTitle);
+                noteXml = m_manager->note_archiver().get_renamed_note_xml (noteXml, baseTitle, noteTitle);
 
                 if (!note_uri.empty()) {
                   // Load in the XML contents of the note file
