@@ -30,21 +30,27 @@
 #include <gtkmm/statusicon.h>
 
 #include "actionmanager.hpp"
+#include "iconmanager.hpp"
 #include "ignote.hpp"
+#include "preferences.hpp"
 #include "remotecontrolproxy.hpp"
 #include "synchronization/syncdialog.hpp"
+#include "synchronization/syncmanager.hpp"
 
 namespace gnote {
 
 class PreferencesDialog;
 class NoteManager;
-class RemoteControlClient;
 
 class GnoteCommandLine
 {
 public:
-  GnoteCommandLine();
+  GnoteCommandLine(IGnote & ignote);
   ~GnoteCommandLine();
+  void set_note_manager(NoteManagerBase & manager)
+    {
+      m_manager = &manager;
+    }
   int execute();
   int immediate_execute();
 
@@ -77,6 +83,8 @@ private:
 
   GOptionContext *m_context;
 
+  IGnote    & m_gnote;
+  NoteManagerBase *m_manager;
   bool        m_use_panel;
   bool        m_background;
   bool        m_shell_search;
@@ -114,6 +122,27 @@ public:
     {
       return *m_manager;
     }
+  virtual IActionManager & action_manager() override
+    {
+      return m_action_manager;
+    }
+  virtual IconManager & icon_manager() override
+    {
+      return m_icon_manager;
+    }
+  virtual notebooks::NotebookManager & notebook_manager() override;
+  virtual sync::SyncManager & sync_manager() override
+    {
+      return *m_sync_manager;
+    }
+  virtual Preferences & preferences()
+    {
+      return m_preferences;
+    }
+  RemoteControlProxy & remote_control()
+    {
+      return m_remote_control;
+    }
 
   void on_preferences_response(int res);
   void on_show_preferences_action(const Glib::VariantBase&);
@@ -133,7 +162,7 @@ public:
     {
       return !is_background();
     }
-  static void register_remote_control(NoteManager & manager, RemoteControlProxy::slot_name_acquire_finish on_finish);
+  void register_remote_control(NoteManager & manager, RemoteControlProxy::slot_name_acquire_finish on_finish);
   virtual void open_note(const Note::Ptr & note) override;
 protected:
   virtual int on_command_line(const Glib::RefPtr<Gio::ApplicationCommandLine> & command_line) override;
@@ -154,11 +183,16 @@ private:
   void register_object();
 
   NoteManager *m_manager;
+  IconManager m_icon_manager;
+  Preferences m_preferences;
+  ActionManager m_action_manager;
+  sync::SyncManager *m_sync_manager;
   Glib::RefPtr<Gtk::IconTheme> m_icon_theme;
   bool m_is_background;
   bool m_is_shell_search;
+  RemoteControlProxy m_remote_control;
   PreferencesDialog *m_prefsdlg;
-  GnoteCommandLine cmd_line;
+  GnoteCommandLine m_cmd_line;
   sync::SyncDialog::Ptr m_sync_dlg;
 };
 
