@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2013,2017 Aurimas Cernius
+ * Copyright (C) 2013,2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,12 +23,10 @@
 #include <glibmm/ustring.h>
 
 #include "tag.hpp"
-#include "base/singleton.hpp"
 
 namespace gnote {
 
 class ITagManager
-  : public base::Singleton<ITagManager>
 {
 public:
   static const char * TEMPLATE_NOTE_SYSTEM_TAG;
@@ -43,7 +41,7 @@ public:
   virtual Tag::Ptr get_system_tag(const Glib::ustring & tag_name) const = 0;
   virtual Tag::Ptr get_or_create_system_tag(const Glib::ustring & name) = 0;
   virtual void remove_tag(const Tag::Ptr & tag) = 0;
-  virtual void all_tags(std::list<Tag::Ptr> &) const = 0;
+  virtual std::vector<Tag::Ptr> all_tags() const = 0;
 };
 
 }
