@@ -1,7 +1,7 @@
  /*
  * gnote
  *
- * Copyright (C) 2010-2017 Aurimas Cernius
+ * Copyright (C) 2010-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 #include <gtkmm/button.h>
 #include <gtkmm/stock.h>
 
+#include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "note.hpp"
 #include "notemanager.hpp"
@@ -46,7 +47,7 @@ namespace gnote {
 
   namespace noteutils {
 
-    void show_deletion_dialog (const std::list<Note::Ptr> & notes, Gtk::Window * parent)
+    void show_deletion_dialog(const Note::List & notes, Gtk::Window * parent)
     {
       Glib::ustring message;
 
@@ -80,9 +81,7 @@ namespace gnote {
 
       int result = dialog.run();
       if (result == 666) {
-        for(Note::List::const_iterator iter = notes.begin();
-            iter != notes.end(); ++iter) {
-          const Note::Ptr & note(*iter);
+        for(auto & note : notes) {
           note->manager().delete_note(note);
         }
       }
@@ -247,9 +246,10 @@ namespace gnote {
     }
   }
 
-  Note::Note(NoteData * _data, const Glib::ustring & filepath, NoteManager & _manager)
-    : NoteBase(_data, filepath, _manager)
-    , m_data(_data)
+  Note::Note(std::unique_ptr<NoteData> _data, const Glib::ustring & filepath, NoteManager & _manager, IGnote & g)
+    : NoteBase(filepath, _manager)
+    , m_gnote(g)
+    , m_data(std::move(_data))
     , m_save_needed(false)
     , m_is_deleting(false)
     , m_note_window_embedded(false)
@@ -257,9 +257,8 @@ namespace gnote {
     , m_window(NULL)
     , m_tag_table(NULL)
   {
-    for(NoteData::TagMap::const_iterator iter = _data->tags().begin();
-        iter != _data->tags().end(); ++iter) {
-      add_tag(iter->second);
+    for(const auto & iter : m_data.data().tags()) {
+      add_tag(iter.second);
     }
     m_save_timeout = new utils::InterruptableTimeout();
     m_save_timeout->signal_timeout.connect(sigc::mem_fun(*this, &Note::on_save_timeout));
@@ -271,52 +270,36 @@ namespace gnote {
     delete m_window;
   }
 
-  /// <summary>
-  /// Creates a New Note with the given values.
-  /// </summary>
-  /// <param name="title">
-  /// A <see cref="System.String"/>
-  /// </param>
-  /// <param name="filepath">
-  /// A <see cref="System.String"/>
-  /// </param>
-  /// <param name="manager">
-  /// A <see cref="NoteManager"/>
-  /// </param>
-  /// <returns>
-  /// A <see cref="Note"/>
-  /// </returns>
   Note::Ptr Note::create_new_note(const Glib::ustring & title,
                                   const Glib::ustring & filename,
-                                  NoteManager & manager)
+                                  NoteManager & manager,
+                                  IGnote & g)
   {
-    NoteData * note_data = new NoteData(url_from_path(filename));
+    auto note_data = std::make_unique<NoteData>(url_from_path(filename));
     note_data->title() = title;
-    sharp::DateTime date(sharp::DateTime::now());
+    auto date(Glib::DateTime::create_now_local());
     note_data->create_date() = date;
     note_data->set_change_date(date);
       
-    return Note::Ptr(new Note(note_data, filename, manager));
+    return std::make_shared<Note>(std::move(note_data), filename, manager, g);
   }
 
-  Note::Ptr Note::create_existing_note(NoteData *data,
-                                 Glib::ustring filepath,
-                                 NoteManager & manager)
+  Note::Ptr Note::create_existing_note(std::unique_ptr<NoteData> data, Glib::ustring filepath, NoteManager & manager, IGnote & g)
   {
-    if (!data->change_date().is_valid()) {
-      sharp::DateTime d(sharp::file_modification_time(filepath));
+    if (!data->change_date()) {
+      auto d(sharp::file_modification_time(filepath));
       data->set_change_date(d);
     }
-    if (!data->create_date().is_valid()) {
-      if(data->change_date().is_valid()) {
+    if (!data->create_date()) {
+      if(data->change_date()) {
         data->create_date() = data->change_date();
       }
       else {
-        sharp::DateTime d(sharp::file_modification_time(filepath));
+        auto d(sharp::file_modification_time(filepath));
         data->create_date() = d;
       }
     }
-    return Note::Ptr(new Note(data, filepath, manager));
+    return std::make_shared<Note>(std::move(data), filepath, manager, g);
   }
 
   void Note::delete_note()
@@ -348,11 +331,11 @@ namespace gnote {
   }
 
   
-  Note::Ptr Note::load(const Glib::ustring & read_file, NoteManager & manager)
+  Note::Ptr Note::load(const Glib::ustring & read_file, NoteManager & manager, IGnote & g)
   {
-    NoteData *data = new NoteData(url_from_path(read_file));
-    NoteArchiver::read(read_file, *data);
-    return create_existing_note(data, read_file, manager);
+    auto data = std::make_unique<NoteData>(url_from_path(read_file));
+    manager.note_archiver().read_file(read_file, *data);
+    return create_existing_note(std::move(data), read_file, manager, g);
   }
 
   
@@ -371,7 +354,7 @@ namespace gnote {
     DBG_OUT("Saving '%s'...", m_data.data().title().c_str());
 
     try {
-      NoteArchiver::write(file_path(), m_data.synchronized_data());
+      manager().note_archiver().write_file(file_path(), m_data.synchronized_data());
     } 
     catch (const sharp::Exception & e) {
       // Probably IOException or UnauthorizedAccessException?
@@ -550,15 +533,15 @@ namespace gnote {
   void Note::process_rename_link_update(const Glib::ustring & old_title)
   {
     NoteBase::List linking_notes = manager().get_notes_linking_to(old_title);
-    const Note::Ptr self = static_pointer_cast<Note>(shared_from_this());
+    const Note::Ptr self = std::static_pointer_cast<Note>(shared_from_this());
 
     if (!linking_notes.empty()) {
-      Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+      Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
       const NoteRenameBehavior behavior
         = static_cast<NoteRenameBehavior>(settings->get_int(Preferences::NOTE_RENAME_BEHAVIOR));
 
       if (NOTE_RENAME_ALWAYS_SHOW_DIALOG == behavior) {
-        NoteRenameDialog *dlg = new NoteRenameDialog(linking_notes, old_title, self);
+        NoteRenameDialog *dlg = new NoteRenameDialog(linking_notes, old_title, self, m_gnote);
         dlg->signal_response().connect([this, dlg, old_title, self](int response) {
           process_rename_link_update_end(response, dlg, old_title, self);
         });
@@ -566,13 +549,13 @@ namespace gnote {
         get_window()->editor()->set_editable(false);
       }
       else if (NOTE_RENAME_ALWAYS_REMOVE_LINKS == behavior) {
-        FOREACH(NoteBase::Ptr & iter, linking_notes) {
+        for(NoteBase::Ptr & iter : linking_notes) {
           iter->remove_links(old_title, self);
           process_rename_link_update_end(Gtk::RESPONSE_NO, NULL, old_title, self);
         }
       }
       else if (NOTE_RENAME_ALWAYS_RENAME_LINKS == behavior) {
-        FOREACH(NoteBase::Ptr & iter, linking_notes) {
+        for(NoteBase::Ptr & iter : linking_notes) {
           iter->rename_links(old_title, self);
           process_rename_link_update_end(Gtk::RESPONSE_NO, NULL, old_title, self);
         }
@@ -587,7 +570,7 @@ namespace gnote {
       NoteRenameDialog *dlg = static_cast<NoteRenameDialog*>(dialog);
       const NoteRenameBehavior selected_behavior = dlg->get_selected_behavior();
       if(Gtk::RESPONSE_CANCEL != response && NOTE_RENAME_ALWAYS_SHOW_DIALOG != selected_behavior) {
-        Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+        Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
         settings->set_int(Preferences::NOTE_RENAME_BEHAVIOR, selected_behavior);
       }
 
@@ -712,7 +695,7 @@ namespace gnote {
   {
     if(!m_buffer) {
       DBG_OUT("Creating buffer for %s", m_data.data().title().c_str());
-      m_buffer = NoteBuffer::create(get_tag_table(), *this);
+      m_buffer = NoteBuffer::create(get_tag_table(), *this, m_gnote.preferences());
       m_data.set_buffer(m_buffer);
 
       m_buffer->signal_changed().connect(
@@ -733,7 +716,7 @@ namespace gnote {
   NoteWindow * Note::create_window()
   {
     if(!m_window) {
-      m_window = new NoteWindow(*this);
+      m_window = new NoteWindow(*this, m_gnote);
       m_window->signal_delete_event().connect(
         sigc::mem_fun(*this, &Note::on_window_destroyed));
 
@@ -761,7 +744,7 @@ namespace gnote {
       m_note_window_embedded = true;
     }
 
-    notebooks::NotebookManager::obj().active_notes_notebook()->add_note(static_pointer_cast<Note>(shared_from_this()));
+    m_gnote.notebook_manager().active_notes_notebook()->add_note(std::static_pointer_cast<Note>(shared_from_this()));
   }
 
   void Note::on_note_window_foregrounded()
@@ -782,7 +765,7 @@ namespace gnote {
 
   bool Note::is_pinned() const
   {
-    Glib::ustring pinned_uris = Preferences::obj()
+    Glib::ustring pinned_uris = m_gnote.preferences()
       .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_string(Preferences::MENU_PINNED_NOTES);
     return pinned_uris.find(uri()) != Glib::ustring::npos;
   }
@@ -791,7 +774,7 @@ namespace gnote {
   void Note::set_pinned(bool pinned) const
   {
     Glib::ustring new_pinned;
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE);
+    Glib::RefPtr<Gio::Settings> settings = m_gnote.preferences().get_schema_settings(Preferences::SCHEMA_GNOTE);
     Glib::ustring old_pinned = settings->get_string(Preferences::MENU_PINNED_NOTES);
     bool is_currently_pinned = old_pinned.find(uri()) != Glib::ustring::npos;
 
@@ -811,7 +794,7 @@ namespace gnote {
       }
     }
     settings->set_string(Preferences::MENU_PINNED_NOTES, new_pinned);
-    notebooks::NotebookManager::obj().signal_note_pin_status_changed(*this, pinned);
+    m_gnote.notebook_manager().signal_note_pin_status_changed(*this, pinned);
   }
 
   void Note::enabled(bool is_enabled)
