@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2015,2017 Aurimas Cernius
+ * Copyright (C) 2011-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 #ifndef __NOTE_HPP_
 #define __NOTE_HPP_
 
-#include <list>
 #include <queue>
 
 #include <gtkmm/textbuffer.h>
@@ -35,6 +34,7 @@
 
 namespace gnote {
 
+class IGnote;
 class NoteManager;
 
 class NoteWindow;
@@ -45,9 +45,8 @@ class NoteDataBufferSynchronizer
   : public NoteDataBufferSynchronizerBase
 {
 public:
-  // takes ownership
-  NoteDataBufferSynchronizer(NoteData * _data)
-    : NoteDataBufferSynchronizerBase(_data)
+  NoteDataBufferSynchronizer(std::unique_ptr<NoteData> _data)
+    : NoteDataBufferSynchronizerBase(std::move(_data))
     {
     }
 
@@ -90,22 +89,26 @@ class Note
   : public NoteBase
 {
 public:
-  typedef shared_ptr<Note> Ptr;
-  typedef weak_ptr<Note> WeakPtr;
-  typedef std::list<Ptr> List;
+  typedef std::shared_ptr<Note> Ptr;
+  typedef std::weak_ptr<Note> WeakPtr;
+  typedef std::vector<Ptr> List;
 
   ~Note();
 
 
   static Note::Ptr create_new_note(const Glib::ustring & title,
                                    const Glib::ustring & filename,
-                                   NoteManager & manager);
+                                   NoteManager & manager,
+                                   IGnote & g);
 
-  static Note::Ptr create_existing_note(NoteData *data,
+  static Note::Ptr create_existing_note(std::unique_ptr<NoteData> data,
                                         Glib::ustring filepath,
-                                        NoteManager & manager);
+                                        NoteManager & manager,
+                                        IGnote & g);
+
+  Note(std::unique_ptr<NoteData> _data, const Glib::ustring & filepath, NoteManager & manager, IGnote & g);
   virtual void delete_note() override;
-  static Note::Ptr load(const Glib::ustring &, NoteManager &);
+  static Note::Ptr load(const Glib::ustring &, NoteManager &, IGnote &);
   virtual void save() override;
   virtual void queue_save(ChangeType c) override;
   using NoteBase::remove_tag;
@@ -183,8 +186,6 @@ private:
   void on_note_window_embedded();
   void on_note_window_foregrounded();
 
-  Note(NoteData * data, const Glib::ustring & filepath, NoteManager & manager);
-
   struct ChildWidgetData
   {
     ChildWidgetData(const Glib::RefPtr<Gtk::TextChildAnchor> & _anchor,
@@ -197,6 +198,7 @@ private:
     Gtk::Widget *widget;
   };
 
+  IGnote &                   m_gnote;
   NoteDataBufferSynchronizer m_data;
   bool                       m_save_needed;
   bool                       m_is_deleting;
@@ -217,7 +219,7 @@ private:
 };
 
 namespace noteutils {
-  void show_deletion_dialog (const std::list<Note::Ptr> & notes, Gtk::Window * parent);
+  void show_deletion_dialog(const Note::List & notes, Gtk::Window * parent);
 }
 
 }
