@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017,2019 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -42,7 +42,6 @@ namespace gnote {
 
 NoteDataBufferSynchronizerBase::~NoteDataBufferSynchronizerBase()
 {
-  delete m_data;
 }
 
 const Glib::ustring & NoteDataBufferSynchronizerBase::text()
@@ -85,7 +84,7 @@ std::vector<Glib::ustring> NoteBase::parse_tags(const xmlNodePtr tagnodes)
 }
 
 
-NoteBase::NoteBase(NoteData *, const Glib::ustring & filepath, NoteManagerBase & _manager)
+NoteBase::NoteBase(const Glib::ustring & filepath, NoteManagerBase & _manager)
   : m_manager(_manager)
   , m_file_path(filepath)
   , m_enabled(true)
@@ -172,14 +171,14 @@ void NoteBase::set_change_type(ChangeType c)
   {
   case CONTENT_CHANGED:
     // NOTE: Updating ChangeDate automatically updates MetdataChangeDate to match.
-    data_synchronizer().data().set_change_date(sharp::DateTime::now());
+    data_synchronizer().data().set_change_date(Glib::DateTime::create_now_local());
     break;
   case OTHER_DATA_CHANGED:
     // Only update MetadataChangeDate.  Used by sync/etc
     // to know when non-content note data has changed,
     // but order of notes in menu and search UI is
     // unaffected.
-    data_synchronizer().data().metadata_change_date() = sharp::DateTime::now();
+    data_synchronizer().data().metadata_change_date() = Glib::DateTime::create_now_local();
     break;
   default:
     break;
@@ -189,7 +188,7 @@ void NoteBase::set_change_type(ChangeType c)
 void NoteBase::save()
 {
   try {
-    NoteArchiver::write(m_file_path, data_synchronizer().data());
+    m_manager.note_archiver().write_file(m_file_path, data_synchronizer().data());
   } 
   catch (const sharp::Exception & e) {
     // Probably IOException or UnauthorizedAccessException?
@@ -281,7 +280,7 @@ bool NoteBase::contains_tag(const Tag::Ptr & tag) const
 
 Glib::ustring NoteBase::get_complete_note_xml()
 {
-  return NoteArchiver::write_string(data_synchronizer().synchronized_data());
+  return m_manager.note_archiver().write_string(data_synchronizer().synchronized_data());
 }
 
 void NoteBase::set_xml_content(const Glib::ustring & xml)
@@ -337,7 +336,7 @@ void NoteBase::load_foreign_note_xml(const Glib::ustring & foreignNoteXml, Chang
         if(doc2) {
           std::vector<Glib::ustring> tag_strings = parse_tags(doc2->children);
           for(const Glib::ustring & tag_str : tag_strings) {
-            Tag::Ptr tag = ITagManager::obj().get_or_create_tag(tag_str);
+            Tag::Ptr tag = m_manager.tag_manager().get_or_create_tag(tag_str);
             new_tags.push_back(tag);
           }
           xmlFreeDoc(doc2);
@@ -384,17 +383,17 @@ NoteData & NoteBase::data()
   return data_synchronizer().synchronized_data();
 }
 
-const sharp::DateTime & NoteBase::create_date() const
+const Glib::DateTime & NoteBase::create_date() const
 {
   return data_synchronizer().data().create_date();
 }
 
-const sharp::DateTime & NoteBase::change_date() const
+const Glib::DateTime & NoteBase::change_date() const
 {
   return data_synchronizer().data().change_date();
 }
 
-const sharp::DateTime & NoteBase::metadata_change_date() const
+const Glib::DateTime & NoteBase::metadata_change_date() const
 {
   return data_synchronizer().data().metadata_change_date();
 }
@@ -402,7 +401,7 @@ const sharp::DateTime & NoteBase::metadata_change_date() const
 bool NoteBase::is_new() const
 {
   const NoteDataBufferSynchronizerBase & sync(data_synchronizer());
-  return sync.data().create_date().is_valid() && (sync.data().create_date() > sharp::DateTime::now().add_hours(-24));
+  return sync.data().create_date() && (sync.data().create_date() > Glib::DateTime::create_now_local().add_hours(-24));
 }
 
 void NoteBase::enabled(bool is_enabled)
@@ -414,14 +413,6 @@ void NoteBase::enabled(bool is_enabled)
 
 const char *NoteArchiver::CURRENT_VERSION = "0.3";
 
-//instance
-NoteArchiver NoteArchiver::s_obj;
-
-void NoteArchiver::read(const Glib::ustring & read_file, NoteData & data)
-{
-  return obj().read_file(read_file, data);
-}
-
 void NoteArchiver::read_file(const Glib::ustring & file, NoteData & data)
 {
   Glib::ustring version;
@@ -432,7 +423,7 @@ void NoteArchiver::read_file(const Glib::ustring & file, NoteData & data)
       // Note has old format, so rewrite it.  No need
       // to reread, since we are not adding anything.
       DBG_OUT("Updating note XML from %s to newest format...", version.c_str());
-      NoteArchiver::write(file, data);
+      write_file(file, data);
     }
     catch(sharp::Exception & e) {
       // write failure, but not critical
@@ -495,7 +486,7 @@ void NoteArchiver::_read(sharp::XmlReader & xml, NoteData & data, Glib::ustring
         if(doc2) {
           std::vector<Glib::ustring> tag_strings = NoteBase::parse_tags(doc2->children);
           for(const Glib::ustring & tag_str : tag_strings) {
-            Tag::Ptr tag = ITagManager::obj().get_or_create_tag(tag_str);
+            Tag::Ptr tag = m_manager.tag_manager().get_or_create_tag(tag_str);
             data.tags()[tag->normalized_name()] = tag;
           }
           xmlFreeDoc(doc2);
@@ -517,18 +508,13 @@ Glib::ustring NoteArchiver::write_string(const NoteData & note)
 {
   Glib::ustring str;
   sharp::XmlWriter xml;
-  obj().write(xml, note);
+  write(xml, note);
   xml.close();
   str = xml.to_string();
   return str;
 }
   
 
-void NoteArchiver::write(const Glib::ustring & write_file, const NoteData & data)
-{
-  obj().write_file(write_file, data);
-}
-
 void NoteArchiver::write_file(const Glib::ustring & _write_file, const NoteData & data)
 {
   try {
@@ -589,7 +575,7 @@ void NoteArchiver::write(sharp::XmlWriter & xml, const NoteData & data)
   xml.write_string(sharp::XmlConvert::to_string(data.metadata_change_date()));
   xml.write_end_element();
 
-  if(data.create_date().is_valid()) {
+  if(data.create_date()) {
     xml.write_start_element("", "create-date", "");
     xml.write_string(sharp::XmlConvert::to_string(data.create_date()));
     xml.write_end_element();
