@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -23,12 +23,11 @@
 #define _NOTEBASE_HPP_
 
 #include <map>
+#include <vector>
 
 #include <glibmm/ustring.h>
 #include <sigc++/signal.h>
 
-#include "base/macros.hpp"
-#include "base/singleton.hpp"
 #include "tag.hpp"
 #include "sharp/datetime.hpp"
 #include "sharp/xmlreader.hpp"
@@ -69,28 +68,28 @@ public:
     { 
       return m_text;
     }
-  const sharp::DateTime & create_date() const
+  const Glib::DateTime & create_date() const
     {
       return m_create_date;
     }
-  sharp::DateTime & create_date()
+  Glib::DateTime & create_date()
     {
       return m_create_date;
     }
-  const sharp::DateTime & change_date() const
+  const Glib::DateTime & change_date() const
     {
       return m_change_date;
     }
-  void set_change_date(const sharp::DateTime & date)
+  void set_change_date(const Glib::DateTime & date)
     {
       m_change_date = date;
       m_metadata_change_date = date;
     }
-  const sharp::DateTime & metadata_change_date() const
+  const Glib::DateTime & metadata_change_date() const
     {
       return m_metadata_change_date;
     }
-  sharp::DateTime & metadata_change_date()
+  Glib::DateTime & metadata_change_date()
     {
       return m_metadata_change_date;
     }
@@ -142,9 +141,9 @@ private:
   const Glib::ustring m_uri;
   Glib::ustring     m_title;
   Glib::ustring     m_text;
-  sharp::DateTime             m_create_date;
-  sharp::DateTime             m_change_date;
-  sharp::DateTime             m_metadata_change_date;
+  Glib::DateTime    m_create_date;
+  Glib::DateTime    m_change_date;
+  Glib::DateTime    m_metadata_change_date;
   int               m_cursor_pos;
   int               m_selection_bound_pos;
   int               m_width, m_height;
@@ -156,8 +155,8 @@ private:
 class NoteDataBufferSynchronizerBase
 {
 public:
-  NoteDataBufferSynchronizerBase(NoteData *_data)
-    : m_data(_data)
+  NoteDataBufferSynchronizerBase(std::unique_ptr<NoteData> && _data)
+    : m_data(std::move(_data))
     {}
   virtual ~NoteDataBufferSynchronizerBase();
   const NoteData & data() const
@@ -179,23 +178,23 @@ public:
   virtual const Glib::ustring & text();
   virtual void set_text(const Glib::ustring & t);
 private:
-  NoteData *m_data;
+  std::unique_ptr<NoteData> m_data;
 };
 
 
 class NoteBase
-  : public enable_shared_from_this<NoteBase>
+  : public std::enable_shared_from_this<NoteBase>
   , public sigc::trackable
 {
 public:
-  typedef shared_ptr<NoteBase> Ptr;
-  typedef weak_ptr<NoteBase> WeakPtr;
-  typedef std::list<Ptr> List;
+  typedef std::shared_ptr<NoteBase> Ptr;
+  typedef std::weak_ptr<NoteBase> WeakPtr;
+  typedef std::vector<Ptr> List;
 
   static Glib::ustring url_from_path(const Glib::ustring &);
-  static void parse_tags(const xmlNodePtr tagnodes, std::list<Glib::ustring> & tags);
+  static std::vector<Glib::ustring> parse_tags(const xmlNodePtr tagnodes);
 
-  NoteBase(NoteData *_data, const Glib::ustring & filepath, NoteManagerBase & manager);
+  NoteBase(const Glib::ustring & filepath, NoteManagerBase & manager);
 
   NoteManagerBase & manager()
     {
@@ -235,13 +234,13 @@ public:
     }
   virtual void set_xml_content(const Glib::ustring & xml);
   void load_foreign_note_xml(const Glib::ustring & foreignNoteXml, ChangeType changeType);
-  void get_tags(std::list<Tag::Ptr> &) const;
+  std::vector<Tag::Ptr> get_tags() const;
   const NoteData & data() const;
   NoteData & data();
 
-  const sharp::DateTime & create_date() const;
-  const sharp::DateTime & change_date() const;
-  const sharp::DateTime & metadata_change_date() const;
+  const Glib::DateTime & create_date() const;
+  const Glib::DateTime & change_date() const;
+  const Glib::DateTime & metadata_change_date() const;
   bool is_new() const;
   bool enabled() const
     {
@@ -273,16 +272,16 @@ private:
 
 
 class NoteArchiver
-  : public base::Singleton<NoteArchiver>
 {
 public:
   static const char *CURRENT_VERSION;
 
-  static void read(const Glib::ustring & read_file, NoteData & data);
-  static Glib::ustring write_string(const NoteData & data);
-  static void write(const Glib::ustring & write_file, const NoteData & data);
+  explicit NoteArchiver(NoteManagerBase & manager)
+    : m_manager(manager)
+  {}
   void read_file(const Glib::ustring & file, NoteData & data);
   void read(sharp::XmlReader & xml, NoteData & data);
+  Glib::ustring write_string(const NoteData & data);
   void write_file(const Glib::ustring & write_file, const NoteData & data);
   void write(sharp::XmlWriter & xml, const NoteData & data);
 
@@ -290,8 +289,8 @@ public:
   Glib::ustring get_title_from_note_xml(const Glib::ustring & noteXml) const;
 protected:
   void _read(sharp::XmlReader & xml, NoteData & data, Glib::ustring & version);
-
-  static NoteArchiver s_obj;
+private:
+  NoteManagerBase & m_manager;
 };
 
 
