@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -26,7 +26,6 @@
 #include "notemanager.hpp"
 #include "notebooks/notebook.hpp"
 #include "notebooks/notebookmanager.hpp"
-#include "itagmanager.hpp"
 
 namespace gnote {
 namespace notebooks {
@@ -35,10 +34,10 @@ namespace notebooks {
   const char * Notebook::NOTEBOOK_TAG_PREFIX = "notebook:";
   Tag::Ptr Notebook::s_template_tag;
 
-  Tag::Ptr Notebook::template_tag()
+  Tag::Ptr Notebook::template_tag() const
   {
     if(s_template_tag == NULL) {
-      s_template_tag = ITagManager::obj().get_or_create_system_tag(
+      s_template_tag = m_note_manager.tag_manager().get_or_create_system_tag(
         ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
     }
 
@@ -54,14 +53,7 @@ namespace notebooks {
     return note->contains_tag(tag);
   }
 
-  /// <summary>
-  /// Construct a new Notebook with a given name
-  /// </summary>
-  /// <param name="name">
-  /// A <see cref="System.String"/>.  This is the name that will be used
-  /// to identify the notebook.
-  /// </param>
-  Notebook::Notebook(NoteManager & manager, const Glib::ustring & name, bool is_special)
+  Notebook::Notebook(NoteManagerBase & manager, const Glib::ustring & name, bool is_special)
     : m_note_manager(manager)
   {
     // is special assume the name as is, and we don't want a tag.
@@ -70,18 +62,12 @@ namespace notebooks {
     }
     else {
       set_name(name);
-      m_tag = ITagManager::obj().get_or_create_system_tag(
+      m_tag = manager.tag_manager().get_or_create_system_tag(
         Glib::ustring(NOTEBOOK_TAG_PREFIX) + name);
     }
   }
 
-  /// <summary>
-  /// Construct a new Notebook with the specified notebook system tag.
-  /// </summary>
-  /// <param name="notebookTag">
-  /// A <see cref="Tag"/>.  This must be a system notebook tag.
-  /// </param>
-  Notebook::Notebook(NoteManager & manager, const Tag::Ptr & notebookTag)
+  Notebook::Notebook(NoteManagerBase & manager, const Tag::Ptr & notebookTag)
     : m_note_manager(manager)
   {
   // Parse the notebook name from the tag name
@@ -127,15 +113,14 @@ namespace notebooks {
   {
     Note::Ptr note;
     Tag::Ptr templ_tag = template_tag();
-    Tag::Ptr notebook_tag = ITagManager::obj().get_system_tag(NOTEBOOK_TAG_PREFIX + get_name());
+    Tag::Ptr notebook_tag = m_note_manager.tag_manager().get_system_tag(NOTEBOOK_TAG_PREFIX + get_name());
     if(!templ_tag || !notebook_tag) {
       return note;
     }
-    std::list<NoteBase*> notes;
-    templ_tag->get_notes(notes);
-    FOREACH(NoteBase *n, notes) {
+    auto notes = templ_tag->get_notes();
+    for(NoteBase *n : notes) {
       if(n->contains_tag(notebook_tag)) {
-        note = static_pointer_cast<Note>(n->shared_from_this());
+        note = std::static_pointer_cast<Note>(n->shared_from_this());
         break;
       }
     }
@@ -150,14 +135,13 @@ namespace notebooks {
     if (!note) {
       Glib::ustring title = m_default_template_note_title;
       if(m_note_manager.find(title)) {
-        std::list<NoteBase*> tag_notes;
-        m_tag->get_notes(tag_notes);
+        auto tag_notes = m_tag->get_notes();
         title = m_note_manager.get_unique_name(title);
       }
       note = m_note_manager.create(title, NoteManager::get_note_template_content (title));
           
       // Select the initial text
-      NoteBuffer::Ptr buffer = static_pointer_cast<Note>(note)->get_buffer();
+      NoteBuffer::Ptr buffer = std::static_pointer_cast<Note>(note)->get_buffer();
       buffer->select_note_body();
 
       // Flag this as a template note
@@ -167,13 +151,13 @@ namespace notebooks {
       // Add on the notebook system tag so Tomboy
       // will persist the tag/notebook across sessions
       // if no other notes are added to the notebook.
-      Tag::Ptr notebook_tag = ITagManager::obj().get_or_create_system_tag(NOTEBOOK_TAG_PREFIX + get_name());
+      Tag::Ptr notebook_tag = m_note_manager.tag_manager().get_or_create_system_tag(NOTEBOOK_TAG_PREFIX + get_name());
       note->add_tag (notebook_tag);
         
       note->queue_save (CONTENT_CHANGED);
     }
 
-    return static_pointer_cast<Note>(note);
+    return std::static_pointer_cast<Note>(note);
   }
 
   Note::Ptr Notebook::create_notebook_note()
@@ -187,7 +171,7 @@ namespace notebooks {
     // Add the notebook tag
     note->add_tag(m_tag);
 
-    return static_pointer_cast<Note>(note);
+    return std::static_pointer_cast<Note>(note);
   }
 
   /// <summary>
@@ -210,7 +194,7 @@ namespace notebooks {
 
   bool Notebook::add_note(const Note::Ptr & note)
   {
-    NotebookManager::obj().move_note_to_notebook(note, shared_from_this());
+    m_note_manager.notebook_manager().move_note_to_notebook(note, shared_from_this());
     return true;
   }
 
