@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2015,2017 Aurimas Cernius
+ * Copyright (C) 2011-2015,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -35,8 +35,8 @@
 #include "notebooks/notebooknewnotemenuitem.hpp"
 #include "notebooks/notebook.hpp"
 #include "iactionmanager.hpp"
+#include "ignote.hpp"
 #include "debug.hpp"
-#include "iconmanager.hpp"
 #include "notemanager.hpp"
 
 namespace gnote {
@@ -57,11 +57,11 @@ namespace gnote {
 
     void NotebookApplicationAddin::initialize ()
     {
-      IActionManager & am(IActionManager::obj());
+      IActionManager & am(ignote().action_manager());
 
       NoteManager & nm(note_manager());
 
-      FOREACH(const NoteBase::Ptr & note, nm.get_notes()) {
+      for(const NoteBase::Ptr & note : nm.get_notes()) {
         note->signal_tag_added.connect(
           sigc::mem_fun(*this, &NotebookApplicationAddin::on_tag_added));
         note->signal_tag_removed.connect(
@@ -76,7 +76,7 @@ namespace gnote {
       am.add_app_action("new-notebook");
       am.get_app_action("new-notebook")->signal_activate().connect(
         sigc::mem_fun(*this, &NotebookApplicationAddin::on_new_notebook_action));
-      am.add_app_menu_item(IActionManager::APP_ACTION_NEW, 300, _("New Note_book..."), "app.new-notebook");
+      am.add_app_menu_item(APP_SECTION_NEW, 300, _("New Note_book..."), "app.new-notebook");
         
       m_initialized = true;
     }
@@ -94,13 +94,14 @@ namespace gnote {
 
     void NotebookApplicationAddin::on_new_notebook_action(const Glib::VariantBase&)
     {
-      NotebookManager::prompt_create_new_notebook (NULL);
+      NotebookManager::prompt_create_new_notebook(ignote(), NULL);
     }
 
 
     void NotebookApplicationAddin::on_tag_added(const NoteBase & note, const Tag::Ptr& tag)
     {
-      if (NotebookManager::obj().is_adding_notebook()) {
+      NotebookManager & manager = ignote().notebook_manager();
+      if (manager.is_adding_notebook()) {
         return;
       }
 
@@ -110,13 +111,11 @@ namespace gnote {
         return;
       }
 
-      Glib::ustring notebookName =
-        sharp::string_substring(tag->name(), megaPrefix.size());
+      Glib::ustring notebookName = sharp::string_substring(tag->name(), megaPrefix.size());
 
-      Notebook::Ptr notebook =
-        NotebookManager::obj().get_or_create_notebook (notebookName);
+      Notebook::Ptr notebook = manager.get_or_create_notebook(notebookName);
 
-      NotebookManager::obj().signal_note_added_to_notebook() (static_cast<const Note&>(note), notebook);
+      manager.signal_note_added_to_notebook() (static_cast<const Note&>(note), notebook);
     }
 
 
@@ -134,13 +133,13 @@ namespace gnote {
       Glib::ustring normalizedNotebookName =
         sharp::string_substring(normalizedTagName, megaPrefix.size());
 
-      Notebook::Ptr notebook =
-        NotebookManager::obj().get_notebook (normalizedNotebookName);
+      NotebookManager & manager = ignote().notebook_manager();
+      Notebook::Ptr notebook = manager.get_notebook(normalizedNotebookName);
       if (!notebook) {
         return;
       }
 
-      NotebookManager::obj().signal_note_removed_from_notebook() (*static_pointer_cast<Note>(note), notebook);
+      manager.signal_note_removed_from_notebook() (*std::static_pointer_cast<Note>(note), notebook);
     }
 
     void NotebookApplicationAddin::on_note_added(const NoteBase::Ptr & note)
