@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -32,51 +32,53 @@
 #include "debug.hpp"
 #include "ignote.hpp"
 #include "notemanager.hpp"
-#include "itagmanager.hpp"
 
 
 namespace gnote {
   namespace notebooks {
 
-    NotebookManager::NotebookManager(NoteManager & manager)
+    NotebookManager::NotebookManager(NoteManagerBase & manager)
       : m_adding_notebook(false)
       , m_active_notes(new ActiveNotesNotebook(manager))
       , m_note_manager(manager)
-   { 
-     m_notebooks = Gtk::ListStore::create(m_column_types);
+    { 
+    }
 
-     m_sortedNotebooks = Gtk::TreeModelSort::create (m_notebooks);
-     m_sortedNotebooks->set_sort_func (
-       0, sigc::ptr_fun(&NotebookManager::compare_notebooks_sort_func));
-     m_sortedNotebooks->set_sort_column (0, Gtk::SORT_ASCENDING);
+    void NotebookManager::init()
+    {
+      m_notebooks = Gtk::ListStore::create(m_column_types);
 
-     m_notebooks_to_display = Gtk::TreeModelFilter::create(m_sortedNotebooks);
-     m_notebooks_to_display->set_visible_func(
-       sigc::mem_fun(*this, &NotebookManager::filter_notebooks_to_display));
-      
-     m_filteredNotebooks = Gtk::TreeModelFilter::create (m_sortedNotebooks);
-     m_filteredNotebooks->set_visible_func(
-       sigc::ptr_fun(&NotebookManager::filter_notebooks));
-      
-     Notebook::Ptr allNotesNotebook(new AllNotesNotebook(manager));
-     Gtk::TreeIter iter = m_notebooks->append ();
-     iter->set_value(0, Notebook::Ptr(allNotesNotebook));
-      
-     Notebook::Ptr unfiledNotesNotebook(new UnfiledNotesNotebook(manager));
-     iter = m_notebooks->append ();
-     iter->set_value(0, Notebook::Ptr(unfiledNotesNotebook));
+      m_sortedNotebooks = Gtk::TreeModelSort::create (m_notebooks);
+      m_sortedNotebooks->set_sort_func (
+        0, sigc::ptr_fun(&NotebookManager::compare_notebooks_sort_func));
+      m_sortedNotebooks->set_sort_column (0, Gtk::SORT_ASCENDING);
 
-     Notebook::Ptr pinned_notes_notebook(new PinnedNotesNotebook(manager));
-     iter = m_notebooks->append();
-     iter->set_value(0, pinned_notes_notebook);
+      m_notebooks_to_display = Gtk::TreeModelFilter::create(m_sortedNotebooks);
+      m_notebooks_to_display->set_visible_func(
+        sigc::mem_fun(*this, &NotebookManager::filter_notebooks_to_display));
 
-     iter = m_notebooks->append();
-     iter->set_value(0, m_active_notes);
-     static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->signal_size_changed
-       .connect(sigc::mem_fun(*this, &NotebookManager::on_active_notes_size_changed));
+      m_filteredNotebooks = Gtk::TreeModelFilter::create (m_sortedNotebooks);
+      m_filteredNotebooks->set_visible_func(
+        sigc::ptr_fun(&NotebookManager::filter_notebooks));
 
-      
-     load_notebooks ();
+      Notebook::Ptr allNotesNotebook(std::make_shared<AllNotesNotebook>(m_note_manager));
+      Gtk::TreeIter iter = m_notebooks->append ();
+      iter->set_value(0, Notebook::Ptr(allNotesNotebook));
+
+      Notebook::Ptr unfiledNotesNotebook(std::make_shared<UnfiledNotesNotebook>(m_note_manager));
+      iter = m_notebooks->append ();
+      iter->set_value(0, Notebook::Ptr(unfiledNotesNotebook));
+
+      Notebook::Ptr pinned_notes_notebook(std::make_shared<PinnedNotesNotebook>(m_note_manager));
+      iter = m_notebooks->append();
+      iter->set_value(0, pinned_notes_notebook);
+
+      iter = m_notebooks->append();
+      iter->set_value(0, m_active_notes);
+      std::static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->signal_size_changed
+        .connect(sigc::mem_fun(*this, &NotebookManager::on_active_notes_size_changed));
+
+      load_notebooks ();
     }
 
 
@@ -125,7 +127,7 @@ namespace gnote {
         
         try {
           m_adding_notebook = true;
-          notebook = Notebook::Ptr(new Notebook(m_note_manager, notebookName));
+          notebook = std::make_shared<Notebook>(m_note_manager, notebookName);
         } 
         catch(...)
         {
@@ -189,12 +191,12 @@ namespace gnote {
         m_notebooks->erase (iter);
 
         // Remove the notebook tag from every note that's in the notebook
-        std::list<NoteBase*> notes;
+        std::vector<NoteBase*> notes;
         Tag::Ptr tag = notebook->get_tag();
         if(tag) {
-          tag->get_notes(notes);
+          notes = tag->get_notes();
         }
-        FOREACH(NoteBase *note, notes) {
+        for(NoteBase *note : notes) {
           note->remove_tag (notebook->get_tag());
           m_note_removed_from_notebook (*static_cast<Note*>(note), notebook);
         }
@@ -246,11 +248,9 @@ namespace gnote {
     /// </returns>
     Notebook::Ptr NotebookManager::get_notebook_from_note(const NoteBase::Ptr & note)
     {
-      std::list<Tag::Ptr> tags;
-      note->get_tags(tags);
-      for(std::list<Tag::Ptr>::const_iterator iter = tags.begin();
-          iter != tags.end(); ++iter) {
-        Notebook::Ptr notebook = get_notebook_from_tag (*iter);
+      std::vector<Tag::Ptr> tags = note->get_tags();
+      for(auto & tag : tags) {
+        Notebook::Ptr notebook = get_notebook_from_tag(tag);
         if (notebook)
           return notebook;
       }
@@ -305,19 +305,16 @@ namespace gnote {
     }
 
 
-    Notebook::Ptr NotebookManager::prompt_create_new_notebook(Gtk::Window *parent)
+    Notebook::Ptr NotebookManager::prompt_create_new_notebook(IGnote & g, Gtk::Window *parent)
     {
-      return prompt_create_new_notebook(parent, Note::List());
+      return prompt_create_new_notebook(g, parent, Note::List());
     }
 
 
-    Notebook::Ptr NotebookManager::prompt_create_new_notebook(Gtk::Window *parent,
-                                                              const Note::List & notesToAdd)
+    Notebook::Ptr NotebookManager::prompt_create_new_notebook(IGnote & g, Gtk::Window *parent, const Note::List & notesToAdd)
     {
       // Prompt the user for the name of a new notebook
-      CreateNotebookDialog dialog(parent,
-                                  (GtkDialogFlags)(GTK_DIALOG_MODAL
-                                                   | GTK_DIALOG_DESTROY_WITH_PARENT));
+      CreateNotebookDialog dialog(parent, (GtkDialogFlags)(GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT), g);
       
       
       int response = dialog.run ();
@@ -325,7 +322,7 @@ namespace gnote {
       if (response != Gtk::RESPONSE_OK)
         return Notebook::Ptr();
       
-      Notebook::Ptr notebook = obj().get_or_create_notebook (notebookName);
+      Notebook::Ptr notebook = g.notebook_manager().get_or_create_notebook (notebookName);
       if (!notebook) {
         DBG_OUT ("Could not create notebook: %s", notebookName.c_str());
       } 
@@ -337,7 +334,7 @@ namespace gnote {
           // Move all the specified notesToAdd into the new notebook
           for(Note::List::const_iterator iter = notesToAdd.begin();
               iter != notesToAdd.end(); ++iter) {
-            obj().move_note_to_notebook (*iter, notebook);
+            g.notebook_manager().move_note_to_notebook (*iter, notebook);
           }
         }
       }
@@ -345,17 +342,7 @@ namespace gnote {
       return notebook;
     }
     
-    /// <summary>
-    /// Prompt the user and delete the notebok (if they say so).
-    /// </summary>
-    /// <param name="parent">
-    /// A <see cref="Gtk.Window"/>
-    /// </param>
-    /// <param name="notebook">
-    /// A <see cref="Notebook"/>
-    /// </param>
-    void NotebookManager::prompt_delete_notebook(Gtk::Window * parent, 
-                                                 const Notebook::Ptr & notebook)
+    void NotebookManager::prompt_delete_notebook(IGnote & g, Gtk::Window * parent, const Notebook::Ptr & notebook)
     {
       // Confirmation Dialog
       utils::HIGMessageDialog dialog(parent,
@@ -375,11 +362,11 @@ namespace gnote {
       // Grab the template note before removing all the notebook tags
       Note::Ptr templateNote = notebook->get_template_note ();
       
-      obj().delete_notebook (notebook);
+      g.notebook_manager().delete_notebook(notebook);
 
       // Delete the template note
       if (templateNote) {
-        obj().note_manager().delete_note(templateNote);
+        g.notebook_manager().note_manager().delete_note(templateNote);
       }
     }
 
@@ -440,8 +427,8 @@ namespace gnote {
       if (!notebook_a || !notebook_b)
         return 0;
 
-      SpecialNotebook::Ptr spec_a = dynamic_pointer_cast<SpecialNotebook>(notebook_a);
-      SpecialNotebook::Ptr spec_b = dynamic_pointer_cast<SpecialNotebook>(notebook_b);
+      SpecialNotebook::Ptr spec_a = std::dynamic_pointer_cast<SpecialNotebook>(notebook_a);
+      SpecialNotebook::Ptr spec_b = std::dynamic_pointer_cast<SpecialNotebook>(notebook_b);
       if(spec_a != 0 && spec_b != 0) {
         return strcmp(spec_a->get_normalized_name().c_str(), spec_b->get_normalized_name().c_str());
       }
@@ -465,12 +452,8 @@ namespace gnote {
     void NotebookManager::load_notebooks()
     {
       Gtk::TreeIter iter;
-      std::list<Tag::Ptr> tags;
-      ITagManager::obj().all_tags(tags);
-      for(std::list<Tag::Ptr>::const_iterator tag_iter = tags.begin();
-          tag_iter != tags.end(); ++tag_iter) {
-        
-        const Tag::Ptr & tag(*tag_iter);
+      auto tags = m_note_manager.tag_manager().all_tags();
+      for(const auto & tag : tags) {
         // Skip over tags that aren't notebooks
         if (!tag->is_system()
             || !Glib::str_has_prefix(tag->name(),
@@ -478,7 +461,7 @@ namespace gnote {
                                      + Notebook::NOTEBOOK_TAG_PREFIX)) {
           continue;
         }
-        Notebook::Ptr notebook(new Notebook(m_note_manager, tag));
+        Notebook::Ptr notebook = std::make_shared<Notebook>(m_note_manager, tag);
         iter = m_notebooks->append ();
         iter->set_value(0, notebook);
         m_notebookMap [notebook->get_normalized_name()] = iter;
@@ -492,7 +475,7 @@ namespace gnote {
     {
       Notebook::Ptr notebook;
       iter->get_value(0, notebook);
-      if (!notebook || dynamic_pointer_cast<SpecialNotebook>(notebook)) {
+      if (!notebook || std::dynamic_pointer_cast<SpecialNotebook>(notebook)) {
         return false;
       }
       return true;
@@ -503,7 +486,7 @@ namespace gnote {
       Notebook::Ptr notebook;
       iter->get_value(0, notebook);
       if(notebook == m_active_notes) {
-        return !static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->empty();
+        return !std::static_pointer_cast<ActiveNotesNotebook>(m_active_notes)->empty();
       }
 
       return true;
