@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,6 +22,7 @@
 #include <glibmm/i18n.h>
 
 #include "iconmanager.hpp"
+#include "ignote.hpp"
 #include "notemanager.hpp"
 #include "notebookmanager.hpp"
 #include "specialnotebooks.hpp"
@@ -38,11 +39,11 @@ Tag::Ptr SpecialNotebook::get_tag() const
 
 Note::Ptr SpecialNotebook::get_template_note() const
 {
-  return static_pointer_cast<Note>(m_note_manager.get_or_create_template_note());
+  return std::static_pointer_cast<Note>(m_note_manager.get_or_create_template_note());
 }
 
 
-AllNotesNotebook::AllNotesNotebook(NoteManager & manager)
+AllNotesNotebook::AllNotesNotebook(NoteManagerBase & manager)
   : SpecialNotebook(manager, _("All"))
 {
 }
@@ -65,13 +66,13 @@ bool AllNotesNotebook::add_note(const Note::Ptr &)
   return false;
 }
 
-Glib::RefPtr<Gdk::Pixbuf> AllNotesNotebook::get_icon()
+Glib::RefPtr<Gdk::Pixbuf> AllNotesNotebook::get_icon(IconManager & m)
 {
-  return IconManager::obj().get_icon(IconManager::FILTER_NOTE_ALL, 22);
+  return m.get_icon(IconManager::FILTER_NOTE_ALL, 22);
 }
 
 
-UnfiledNotesNotebook::UnfiledNotesNotebook(NoteManager & manager)
+UnfiledNotesNotebook::UnfiledNotesNotebook(NoteManagerBase & manager)
   : SpecialNotebook(manager, _("Unfiled"))
 {
 }
@@ -83,7 +84,7 @@ Glib::ustring UnfiledNotesNotebook::get_normalized_name() const
 
 bool UnfiledNotesNotebook::contains_note(const Note::Ptr & note, bool include_system)
 {
-  bool contains = !notebooks::NotebookManager::obj().get_notebook_from_note(note);
+  bool contains = m_note_manager.notebook_manager().get_notebook_from_note(note) != nullptr;
   if(!contains || include_system) {
     return contains;
   }
@@ -92,18 +93,18 @@ bool UnfiledNotesNotebook::contains_note(const Note::Ptr & note, bool include_sy
 
 bool UnfiledNotesNotebook::add_note(const Note::Ptr & note)
 {
-  NotebookManager::obj().move_note_to_notebook(note, Notebook::Ptr());
+  m_note_manager.notebook_manager().move_note_to_notebook(note, Notebook::Ptr());
   return true;
 }
 
-Glib::RefPtr<Gdk::Pixbuf> UnfiledNotesNotebook::get_icon()
+Glib::RefPtr<Gdk::Pixbuf> UnfiledNotesNotebook::get_icon(IconManager & m)
 {
-  return IconManager::obj().get_icon(IconManager::FILTER_NOTE_UNFILED, 22);
+  return m.get_icon(IconManager::FILTER_NOTE_UNFILED, 22);
 }
 
 
-PinnedNotesNotebook::PinnedNotesNotebook(NoteManager & manager)
-  : SpecialNotebook(manager, _("Important"))
+PinnedNotesNotebook::PinnedNotesNotebook(NoteManagerBase & manager)
+  : SpecialNotebook(manager, C_("notebook", "Important"))
 {
 }
 
@@ -123,13 +124,13 @@ bool PinnedNotesNotebook::add_note(const Note::Ptr & note)
   return true;
 }
 
-Glib::RefPtr<Gdk::Pixbuf> PinnedNotesNotebook::get_icon()
+Glib::RefPtr<Gdk::Pixbuf> PinnedNotesNotebook::get_icon(IconManager & m)
 {
-  return IconManager::obj().get_icon(IconManager::PIN_DOWN, 22);
+  return m.get_icon(IconManager::PIN_DOWN, 22);
 }
 
 
-ActiveNotesNotebook::ActiveNotesNotebook(NoteManager & manager)
+ActiveNotesNotebook::ActiveNotesNotebook(NoteManagerBase & manager)
   : SpecialNotebook(manager, _("Active"))
 {
   manager.signal_note_deleted
@@ -159,14 +160,14 @@ bool ActiveNotesNotebook::add_note(const Note::Ptr & note)
   return true;
 }
 
-Glib::RefPtr<Gdk::Pixbuf> ActiveNotesNotebook::get_icon()
+Glib::RefPtr<Gdk::Pixbuf> ActiveNotesNotebook::get_icon(IconManager & m)
 {
-  return IconManager::obj().get_icon(IconManager::ACTIVE_NOTES, 22);
+  return m.get_icon(IconManager::ACTIVE_NOTES, 22);
 }
 
 void ActiveNotesNotebook::on_note_deleted(const NoteBase::Ptr & note)
 {
-  std::set<Note::Ptr>::iterator iter = m_notes.find(static_pointer_cast<Note>(note));
+  std::set<Note::Ptr>::iterator iter = m_notes.find(std::static_pointer_cast<Note>(note));
   if(iter != m_notes.end()) {
     m_notes.erase(iter);
     signal_size_changed();
@@ -181,7 +182,7 @@ bool ActiveNotesNotebook::empty()
 
   // ignore template notes
   Tag::Ptr templ_tag = template_tag();
-  FOREACH(const Note::Ptr & note, m_notes) {
+  for(const Note::Ptr & note : m_notes) {
     if(!note->contains_tag(templ_tag)) {
       return false;
     }
