@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013,2016-2017 Aurimas Cernius
+ * Copyright (C) 2011,2013,2016-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -27,18 +27,19 @@
 #include <glibmm/refptr.h>
 #include <gtkmm/textview.h>
 
-#include "base/macros.hpp"
-#include "preferences.hpp"
 
 namespace gnote {
 
+class Preferences;
+
+
 class NoteEditor
   : public Gtk::TextView
 {
 public:
   typedef Glib::RefPtr<NoteEditor> Ptr;
 
-  NoteEditor(const Glib::RefPtr<Gtk::TextBuffer> & buffer);
+  NoteEditor(const Glib::RefPtr<Gtk::TextBuffer> & buffer, Preferences & preferences);
   static int default_margin()
     {
       return 8;
@@ -62,6 +63,8 @@ private:
   bool button_pressed (GdkEventButton * ev);
   void on_paste_start();
   void on_paste_end();
+
+  Preferences & m_preferences;
 };
 
 
