@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -32,30 +32,28 @@
 #include "addinmanager.hpp"
 #include "ignote.hpp"
 #include "itagmanager.hpp"
-#include "preferences.hpp"
 #include "sharp/directory.hpp"
 #include "sharp/dynamicmodule.hpp"
 
 namespace gnote {
 
-  NoteManager::NoteManager(const Glib::ustring & directory)
-    : NoteManagerBase(directory)
+  NoteManager::NoteManager(IGnote & g)
+    : NoteManagerBase(g)
+    , m_preferences(g.preferences())
+    , m_notebook_manager(*this)
+    , m_addin_mgr(NULL)
+    , m_note_archiver(*this)
   {
-    Glib::ustring backup = directory + "/Backup";
-    
-    _common_init(directory, backup);
   }
 
 
-  void NoteManager::_common_init(const Glib::ustring & directory, const Glib::ustring & backup_directory)
+  void NoteManager::init(const Glib::ustring & directory)
   {
-    m_addin_mgr = NULL;
+    Glib::ustring backup = directory + "/Backup";
+    NoteManagerBase::init(directory, backup);
     bool is_first_run = first_run();
 
-    NoteManagerBase::_common_init(directory, backup_directory);
-
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
-      .get_schema_settings(Preferences::SCHEMA_GNOTE);
+    Glib::RefPtr<Gio::Settings> settings = m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE);
     // Watch the START_NOTE_URI setting and update it so that the
     // StartNoteUri property doesn't generate a call to
     // Preferences.Get () each time it's accessed.
@@ -65,25 +63,22 @@ namespace gnote {
     m_addin_mgr = create_addin_manager ();
 
     if (is_first_run) {
-      std::list<ImportAddin*> l;
-      m_addin_mgr->get_import_addins(l);
+      std::vector<ImportAddin*> l = m_addin_mgr->get_import_addins();
       bool has_imported = false;
 
       if(l.empty()) {
         DBG_OUT("no import plugins");
       }
 
-      for(std::list<ImportAddin*>::iterator iter = l.begin();
-          iter != l.end(); ++iter) {
-
+      for(auto import_addin : l) {
         DBG_OUT("importing");
-        (*iter)->initialize();
-        if((*iter)->want_to_run(*this)) {
-          has_imported |= (*iter)->first_run(*this);
+        import_addin->initialize();
+        if(import_addin->want_to_run(*this)) {
+          has_imported |= import_addin->first_run(*this);
         }
-        AddinInfo addin_info = m_addin_mgr->get_addin_info(**iter);
+        AddinInfo addin_info = m_addin_mgr->get_addin_info(*import_addin);
         if(addin_info.get_attribute("AutoDisable") == "true") {
-          (*iter)->shutdown();
+          import_addin->shutdown();
           m_addin_mgr->get_module(addin_info.id())->enabled(false);
         }
       }
@@ -98,7 +93,8 @@ namespace gnote {
       load_notes ();
     }
 
-    IGnote::obj().signal_quit.connect(sigc::mem_fun(*this, &NoteManager::on_exiting_event));
+    m_notebook_manager.init();
+    m_gnote.signal_quit.connect(sigc::mem_fun(*this, &NoteManager::on_exiting_event));
   }
 
   NoteManager::~NoteManager()
@@ -109,14 +105,14 @@ namespace gnote {
   void NoteManager::on_setting_changed(const Glib::ustring & key)
   {
     if(key == Preferences::START_NOTE_URI) {
-      m_start_note_uri = Preferences::obj()
+      m_start_note_uri = m_preferences
         .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_string(Preferences::START_NOTE_URI);
     }
   }
 
   AddinManager *NoteManager::create_addin_manager()
   {
-    return new AddinManager(*this, IGnote::conf_dir());
+    return new AddinManager(m_gnote, *this, m_preferences, IGnote::conf_dir());
   }
 
   void NoteManager::create_start_notes ()
@@ -168,7 +164,7 @@ namespace gnote {
       NoteBase::Ptr start_note = create (_("Start Here"),
                                 start_note_content);
       start_note->queue_save (CONTENT_CHANGED);
-      Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
+      m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
           Preferences::START_NOTE_URI, start_note->uri());
 
       NoteBase::Ptr links_note = create (_("Using Links in Gnote"),
@@ -182,12 +178,11 @@ namespace gnote {
 
   void NoteManager::load_notes()
   {
-    std::list<Glib::ustring> files;
-    sharp::directory_get_files_with_ext(notes_dir(), ".note", files);
+    std::vector<Glib::ustring> files = sharp::directory_get_files_with_ext(notes_dir(), ".note");
 
     for(auto file_path : files) {
       try {
-        Note::Ptr note = Note::load(file_path, *this);
+        Note::Ptr note = Note::load(file_path, *this, m_gnote);
         add_note(note);
       } 
       catch (const std::exception & e) {
@@ -206,7 +201,7 @@ namespace gnote {
       // Attempt to find an existing Start Here note
       NoteBase::Ptr start_note = find (_("Start Here"));
       if (start_note) {
-        Preferences::obj().get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
+        m_preferences.get_schema_settings(Preferences::SCHEMA_GNOTE)->set_string(
             Preferences::START_NOTE_URI, start_note->uri());
       }
     }
@@ -221,8 +216,8 @@ namespace gnote {
     // Iterating through copy of notes list, because list may be
     // changed when loading addins.
     NoteBase::List notesCopy(m_notes);
-    FOREACH(const NoteBase::Ptr & iter, notesCopy) {
-      Note::Ptr note(static_pointer_cast<Note>(iter));
+    for(const NoteBase::Ptr & iter : notesCopy) {
+      Note::Ptr note(std::static_pointer_cast<Note>(iter));
 
       m_addin_mgr->load_addins_for_note (note);
     }
@@ -230,8 +225,7 @@ namespace gnote {
 
   void NoteManager::migrate_notes(const Glib::ustring & old_note_dir)
   {
-    std::list<Glib::ustring> files;
-    sharp::directory_get_files_with_ext(old_note_dir, ".note", files);
+    std::vector<Glib::ustring> files = sharp::directory_get_files_with_ext(old_note_dir, ".note");
 
     for(auto file : files) {
       const Glib::RefPtr<Gio::File> src = Gio::File::create_for_path(file);
@@ -243,12 +237,10 @@ namespace gnote {
       src->copy(dest, Gio::FILE_COPY_NONE);
     }
 
-    files.clear();
     const Glib::ustring old_backup_dir = Glib::build_filename(
                                          old_note_dir,
                                          "Backup");
-    sharp::directory_get_files_with_ext(old_backup_dir,
-                                        ".note", files);
+    files = sharp::directory_get_files_with_ext(old_backup_dir, ".note");
 
     for(auto file : files) {
       const Glib::RefPtr<Gio::File> src = Gio::File::create_for_path(file);
@@ -270,14 +262,14 @@ namespace gnote {
     // Use a copy of the notes to prevent bug #510442 (crash on exit
     // when iterating the notes to save them.
     NoteBase::List notesCopy(m_notes);
-    FOREACH(const NoteBase::Ptr & note, notesCopy) {
+    for(const NoteBase::Ptr & note : notesCopy) {
       note->save();
     }
   }
 
   NoteBase::Ptr NoteManager::note_load(const Glib::ustring & file_name)
   {
-    return Note::load(file_name, *this);
+    return Note::load(file_name, *this, m_gnote);
   }
 
 
@@ -288,7 +280,7 @@ namespace gnote {
     NoteBase::Ptr new_note = NoteManagerBase::create_new_note(title, guid);
 
     // Select the inital text so typing will overwrite the body text
-    static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
+    std::static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
 
     return new_note;
   }
@@ -300,14 +292,14 @@ namespace gnote {
     NoteBase::Ptr new_note = NoteManagerBase::create_new_note(title, xml_content, guid);
 
     // Load all the addins for the new note
-    m_addin_mgr->load_addins_for_note(static_pointer_cast<Note>(new_note));
+    m_addin_mgr->load_addins_for_note(std::static_pointer_cast<Note>(new_note));
 
     return new_note;
   }
 
   NoteBase::Ptr NoteManager::note_create_new(const Glib::ustring & title, const Glib::ustring & file_name)
   {
-    return Note::create_new_note(title, file_name, *this);
+    return Note::create_new_note(title, file_name, *this, m_gnote);
   }
 
   NoteBase::Ptr NoteManager::get_or_create_template_note()
@@ -315,7 +307,7 @@ namespace gnote {
     NoteBase::Ptr template_note = NoteManagerBase::get_or_create_template_note();
 
     // Select the initial text
-    Glib::RefPtr<NoteBuffer> buffer = static_pointer_cast<Note>(template_note)->get_buffer();
+    Glib::RefPtr<NoteBuffer> buffer = std::static_pointer_cast<Note>(template_note)->get_buffer();
     buffer->select_note_body();
 
     return template_note;
@@ -333,15 +325,15 @@ namespace gnote {
     }
 
     // Copy template note's properties
-    Tag::Ptr template_save_size = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
+    Tag::Ptr template_save_size = m_tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
     if(template_note->data().has_extent() && template_note->contains_tag(template_save_size)) {
       new_note->data().height() = template_note->data().height();
       new_note->data().width() = template_note->data().width();
     }
 
-    Glib::RefPtr<Gtk::TextBuffer> buffer = static_pointer_cast<Note>(new_note)->get_buffer();
+    Glib::RefPtr<Gtk::TextBuffer> buffer = std::static_pointer_cast<Note>(new_note)->get_buffer();
     Gtk::TextIter cursor, selection;
-    Tag::Ptr template_save_selection = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
+    Tag::Ptr template_save_selection = m_tag_manager.get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SELECTION_SYSTEM_TAG);
     if(template_note->contains_tag(template_save_selection)) {
       Glib::ustring template_title = template_note->get_title();
       int cursor_pos = template_note->data().cursor_position();
