@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2010-2014,2016-2017 Aurimas Cernius
+ * Copyright (C) 2010-2014,2016-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -24,7 +24,6 @@
 
 #include "debug.hpp"
 #include "ignote.hpp"
-#include "itagmanager.hpp"
 #include "notemanagerbase.hpp"
 #include "utils.hpp"
 #include "trie.hpp"
@@ -39,7 +38,7 @@ namespace gnote {
 
 bool compare_dates(const NoteBase::Ptr & a, const NoteBase::Ptr & b)
 {
-  return (static_pointer_cast<Note>(a)->change_date() > static_pointer_cast<Note>(b)->change_date());
+  return (std::static_pointer_cast<Note>(a)->change_date() > std::static_pointer_cast<Note>(b)->change_date());
 }
 
 
@@ -89,9 +88,9 @@ Glib::ustring NoteManagerBase::sanitize_xml_content(const Glib::ustring & xml_co
 }
 
 
-NoteManagerBase::NoteManagerBase(const Glib::ustring & directory)
-  : m_trie_controller(NULL)
-  , m_notes_dir(directory)
+NoteManagerBase::NoteManagerBase(IGnote & g)
+  : m_gnote(g)
+  , m_trie_controller(NULL)
 {
 }
 
@@ -102,8 +101,9 @@ NoteManagerBase::~NoteManagerBase()
   }
 }
 
-void NoteManagerBase::_common_init(const Glib::ustring & /*directory*/, const Glib::ustring & backup_directory)
+void NoteManagerBase::init(const Glib::ustring & directory, const Glib::ustring & backup_directory)
 {
+  m_notes_dir = directory;
   m_default_note_template_title = _("New Note Template");
   m_backup_dir = backup_directory;
   bool is_first_run = first_run();
@@ -159,7 +159,7 @@ TrieController *NoteManagerBase::create_trie_controller()
 
 void NoteManagerBase::post_load()
 {
-  m_notes.sort(compare_dates);
+  std::sort(m_notes.begin(), m_notes.end(), compare_dates);
 
   // Update the trie so addins can access it, if they want.
   m_trie_controller->update ();
@@ -179,7 +179,7 @@ NoteBase::List NoteManagerBase::get_notes_linking_to(const Glib::ustring & title
 {
   Glib::ustring tag = "<link:internal>" + utils::XmlEncoder::encode(title) + "</link:internal>";
   NoteBase::List result;
-  FOREACH(const NoteBase::Ptr & note, m_notes) {
+  for(const NoteBase::Ptr & note : m_notes) {
     if(note->get_title() != title) {
       if(note->get_complete_note_xml().find(tag) != Glib::ustring::npos) {
         result.push_back(note);
@@ -189,30 +189,30 @@ NoteBase::List NoteManagerBase::get_notes_linking_to(const Glib::ustring & title
   return result;
 }
 
-void NoteManagerBase::add_note(const NoteBase::Ptr & note)
+void NoteManagerBase::add_note(NoteBase::Ptr note)
 {
   if(note) {
     note->signal_renamed.connect(sigc::mem_fun(*this, &NoteManagerBase::on_note_rename));
     note->signal_saved.connect(sigc::mem_fun(*this, &NoteManagerBase::on_note_save));
-    m_notes.push_back(note);
+    m_notes.push_back(std::move(note));
   }
 }
 
 void NoteManagerBase::on_note_rename(const NoteBase::Ptr & note, const Glib::ustring & old_title)
 {
   signal_note_renamed(note, old_title);
-  m_notes.sort(compare_dates);
+  std::sort(m_notes.begin(), m_notes.end(), compare_dates);
 }
 
 void NoteManagerBase::on_note_save (const NoteBase::Ptr & note)
 {
   signal_note_saved(note);
-  m_notes.sort(compare_dates);
+  std::sort(m_notes.begin(), m_notes.end(), compare_dates);
 }
 
 NoteBase::Ptr NoteManagerBase::find(const Glib::ustring & linked_title) const
 {
-  FOREACH(const NoteBase::Ptr & note, m_notes) {
+  for(const NoteBase::Ptr & note : m_notes) {
     if(note->get_title().lowercase() == linked_title.lowercase()) {
       return note;
     }
@@ -222,7 +222,7 @@ NoteBase::Ptr NoteManagerBase::find(const Glib::ustring & linked_title) const
 
 NoteBase::Ptr NoteManagerBase::find_by_uri(const Glib::ustring & uri) const
 {
-  FOREACH(const NoteBase::Ptr & note, m_notes) {
+  for(const NoteBase::Ptr & note : m_notes) {
     if (note->uri() == uri) {
       return note;
     }
@@ -257,7 +257,7 @@ NoteBase::Ptr NoteManagerBase::create_note_from_template(const Glib::ustring & t
                                                          const Glib::ustring & guid)
 {
   Glib::ustring new_title(title);
-  Tag::Ptr template_save_title = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
+  Tag::Ptr template_save_title = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_TITLE_SYSTEM_TAG);
   if(template_note->contains_tag(template_save_title)) {
     new_title = get_unique_name(template_note->get_title());
   }
@@ -271,7 +271,7 @@ NoteBase::Ptr NoteManagerBase::create_note_from_template(const Glib::ustring & t
   NoteBase::Ptr new_note = create_new_note(new_title, xml_content, guid);
 
   // Copy template note's properties
-  Tag::Ptr template_save_size = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
+  Tag::Ptr template_save_size = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SAVE_SIZE_SYSTEM_TAG);
   if(template_note->data().has_extent() && template_note->contains_tag(template_save_size)) {
     new_note->data().height() = template_note->data().height();
     new_note->data().width() = template_note->data().width();
@@ -319,7 +319,7 @@ NoteBase::Ptr NoteManagerBase::create_new_note(Glib::ustring title, const Glib::
   NoteBase::Ptr new_note = create_new_note(title, content, guid);
 
   // Select the inital text so typing will overwrite the body text
-  static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
+  std::static_pointer_cast<Note>(new_note)->get_buffer()->select_note_body();
 
   return new_note;
 }
@@ -379,7 +379,7 @@ NoteBase::Ptr NoteManagerBase::get_or_create_template_note()
     }
 
     // Flag this as a template note
-    Tag::Ptr template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    Tag::Ptr template_tag = tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
     template_note->add_tag(template_tag);
 
     template_note->queue_save(CONTENT_CHANGED);
@@ -428,15 +428,14 @@ Glib::ustring NoteManagerBase::make_new_file_name(const Glib::ustring & guid) co
 NoteBase::Ptr NoteManagerBase::find_template_note() const
 {
   NoteBase::Ptr template_note;
-  Tag::Ptr template_tag = ITagManager::obj().get_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+  Tag::Ptr template_tag = tag_manager().get_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
   if(!template_tag) {
     return template_note;
   }
-  std::list<NoteBase*> notes;
-  template_tag->get_notes(notes);
-  FOREACH(NoteBase *iter, notes) {
+  auto notes = template_tag->get_notes();
+  for(NoteBase *iter : notes) {
     NoteBase::Ptr note = iter->shared_from_this();
-    if(!notebooks::NotebookManager::obj().get_notebook_from_note(note)) {
+    if(!m_gnote.notebook_manager().get_notebook_from_note(note)) {
       template_note = note;
       break;
     }
@@ -466,7 +465,12 @@ void NoteManagerBase::delete_note(const NoteBase::Ptr & note)
     }
   }
 
-  m_notes.remove(note);
+  for(auto iter = m_notes.begin(); iter != m_notes.end(); ++iter) {
+    if(*iter == note) {
+      m_notes.erase(iter);
+      break;
+    }
+  }
   note->delete_note();
 
   DBG_OUT("Deleting note '%s'.", note->get_title().c_str());
@@ -548,7 +552,7 @@ void TrieController::update()
   }
   m_title_trie = new TrieTree<NoteBase::WeakPtr>(false /* !case_sensitive */);
 
-  FOREACH(const NoteBase::Ptr & note, m_manager.get_notes()) {
+  for(const NoteBase::Ptr & note : m_manager.get_notes()) {
     m_title_trie->add_keyword(note->get_title(), note);
   }
   m_title_trie->compute_failure_graph();
