@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 #include "debug.hpp"
 #include "notetag.hpp"
 #include "noteeditor.hpp"
+#include "utils.hpp"
 
 namespace gnote {
 
@@ -340,11 +341,10 @@ namespace gnote {
     }
   }
   
-  DepthNoteTag::DepthNoteTag(int depth, Pango::Direction direction)
+  DepthNoteTag::DepthNoteTag(int depth)
     : NoteTag("depth:" + TO_STRING(depth) 
-              + ":" + TO_STRING((int)direction))
+              + ":" + TO_STRING((int)Pango::DIRECTION_LTR))
     , m_depth(depth)
-    , m_direction(direction)
   {
   }
 
@@ -562,23 +562,16 @@ namespace gnote {
   }
   
 
-  DepthNoteTag::Ptr NoteTagTable::get_depth_tag(int depth, Pango::Direction direction)
+  DepthNoteTag::Ptr NoteTagTable::get_depth_tag(int depth)
   {
-    Glib::ustring name = "depth:" + TO_STRING(depth) + ":" + TO_STRING((int)direction);
+    Glib::ustring name = "depth:" + TO_STRING(depth) + ":" + TO_STRING((int)Pango::DIRECTION_LTR);
 
     DepthNoteTag::Ptr tag = DepthNoteTag::Ptr::cast_dynamic(lookup(name));
 
     if (!tag) {
-      tag = DepthNoteTag::Ptr(new DepthNoteTag (depth, direction));
+      tag = DepthNoteTag::Ptr(new DepthNoteTag(depth));
       tag->property_indent().set_value(-14);
-
-      if (direction == Pango::DIRECTION_RTL) {
-        tag->property_right_margin().set_value((depth+1) * 25);
-      }
-      else {
-        tag->property_left_margin().set_value((depth+1) * 25);
-      }
-
+      tag->property_left_margin().set_value((depth+1) * 25);
       tag->property_pixels_below_lines().set_value(4);
       tag->property_scale().set_value(Pango::SCALE_MEDIUM);
       add (tag);
@@ -624,7 +617,7 @@ namespace gnote {
   
   void NoteTagTable::on_tag_removed(const Glib::RefPtr<Gtk::TextTag> & tag)
   {
-    m_added_tags.remove(tag);
+    utils::remove_swap_back(m_added_tags, tag);
 
     NoteTag::Ptr note_tag = NoteTag::Ptr::cast_dynamic(tag);
     if (note_tag) {
