@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2017 Aurimas Cernius
+ * Copyright (C) 2011-2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -33,7 +33,6 @@
 #include <gtkmm/textview.h>
 #include <gtkmm/scrolledwindow.h>
 
-#include "base/macros.hpp"
 #include "mainwindowembeds.hpp"
 #include "note.hpp"
 #include "undo.hpp"
@@ -44,7 +43,8 @@
 
 namespace gnote {
 
-  class Note;
+class IconManager;
+
 
 class NoteTextMenu
   : public Gtk::PopoverMenu
@@ -119,10 +119,10 @@ private:
   void cleanup_matches();
   void find_matches_in_buffer(const Glib::RefPtr<NoteBuffer> & buffer, 
                               const std::vector<Glib::ustring> & words,
-                              std::list<Match> & matches);
+                              std::vector<Match> & matches);
 
   Note           & m_note;
-  std::list<Match> m_current_matches;
+  std::vector<Match> m_current_matches;
 };
 
 class NoteWindow 
@@ -133,7 +133,7 @@ class NoteWindow
   , public HasActions
 {
 public:
-  NoteWindow(Note &);
+  NoteWindow(Note &, IGnote &);
   ~NoteWindow();
 
   virtual Glib::ustring get_name() const override;
@@ -193,7 +193,7 @@ public:
     virtual void reference() const override;
     virtual void unreference() const override;
   };
-  virtual std::vector<Gtk::Widget*> get_popover_widgets() override;
+  virtual std::vector<PopoverWidget> get_popover_widgets() override;
   virtual std::vector<MainWindowAction::Ptr> get_widget_actions() override;
 
   void set_size(int width, int height)
@@ -223,8 +223,8 @@ public:
       return m_enabled;
     }
 private:
-  static Glib::RefPtr<Gio::Icon> get_icon_pin_active();
-  static Glib::RefPtr<Gio::Icon> get_icon_pin_down();
+  static Glib::RefPtr<Gio::Icon> get_icon_pin_active(IconManager & icon_manager);
+  static Glib::RefPtr<Gio::Icon> get_icon_pin_down(IconManager & icon_manager);
 
   void on_delete_button_clicked(const Glib::VariantBase&);
   void on_selection_mark_set(const Gtk::TextIter&, const Glib::RefPtr<Gtk::TextMark>&);
@@ -248,6 +248,7 @@ private:
   void on_text_button_clicked();
 
   Note                        & m_note;
+  IGnote                      & m_gnote;
   Glib::ustring                 m_name;
   int                           m_height;
   int                           m_width;
