@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -22,15 +22,14 @@
 
 
 #include "sharp/string.hpp"
-#include "notemanager.hpp"
+#include "notemanagerbase.hpp"
 #include "search.hpp"
-#include "itagmanager.hpp"
 #include "utils.hpp"
 
 namespace gnote {
 
 
-  Search::Search(NoteManager & manager)
+  Search::Search(NoteManagerBase & manager)
     : m_manager(manager)
   {
   }
@@ -50,13 +49,13 @@ namespace gnote {
     // Used for matching in the raw note XML
     std::vector<Glib::ustring> encoded_words;
     Search::split_watching_quotes(encoded_words, utils::XmlEncoder::encode(search_text));
-    ResultsPtr temp_matches(new Results);
+    ResultsPtr temp_matches(std::make_shared<Results>());
       
       // Skip over notes that are template notes
-    Tag::Ptr template_tag = ITagManager::obj().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
+    Tag::Ptr template_tag = m_manager.tag_manager().get_or_create_system_tag(ITagManager::TEMPLATE_NOTE_SYSTEM_TAG);
 
-    FOREACH(const NoteBase::Ptr & iter, m_manager.get_notes()) {
-      Note::Ptr note(static_pointer_cast<Note>(iter));
+    for(const NoteBase::Ptr & iter : m_manager.get_notes()) {
+      Note::Ptr note(std::static_pointer_cast<Note>(iter));
 
       // Skip template notes
       if (note->contains_tag (template_tag)) {
