@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2014,2017 Aurimas Cernius
+ * Copyright (C) 2012-2014,2017,2019-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,9 +21,6 @@
 #ifndef _SYNCHRONIZATION_ISYNCMANAGER_HPP_
 #define _SYNCHRONIZATION_ISYNCMANAGER_HPP_
 
-#include <list>
-
-#include "base/macros.hpp"
 #include "note.hpp"
 #include "syncui.hpp"
 #include "syncutils.hpp"
@@ -37,10 +34,9 @@ public:
   Glib::ustring client_id;
   Glib::ustring transaction_id;
   int renew_count;
-  sharp::TimeSpan duration;
+  Glib::TimeSpan duration;
   int revision;
 
-  SyncLockInfo();
   explicit SyncLockInfo(const Glib::ustring & client);
   Glib::ustring hash_string();
 };
@@ -48,14 +44,12 @@ public:
 class SyncClient
 {
 public:
-  typedef shared_ptr<SyncClient> Ptr;
-
   virtual ~SyncClient();
 
   virtual int last_synchronized_revision() = 0;
   virtual void last_synchronized_revision(int) = 0;
-  virtual sharp::DateTime last_sync_date() = 0;
-  virtual void last_sync_date(const sharp::DateTime &) = 0;
+  virtual Glib::DateTime last_sync_date() = 0;
+  virtual void last_sync_date(const Glib::DateTime &) = 0;
   virtual int get_revision(const NoteBase::Ptr & note) = 0;
   virtual void set_revision(const NoteBase::Ptr & note, int revision) = 0;
   virtual std::map<Glib::ustring, Glib::ustring> deleted_note_titles() = 0;
@@ -65,7 +59,6 @@ public:
 };
 
 class ISyncManager
-  : public base::Singleton<ISyncManager>
 {
 public:
   virtual ~ISyncManager();
@@ -75,22 +68,21 @@ public:
   virtual void resolve_conflict(SyncTitleConflictResolution resolution) = 0;
   virtual bool synchronized_note_xml_matches(const Glib::ustring & noteXml1, const Glib::ustring & noteXml2) = 0;
   virtual SyncState state() const = 0;
+  virtual SyncUtils & utils() = 0;
 };
 
 class SyncServer
 {
 public:
-  typedef shared_ptr<SyncServer> Ptr;
-
   virtual ~SyncServer();
 
   virtual bool begin_sync_transaction() = 0;
   virtual bool commit_sync_transaction() = 0;
   virtual bool cancel_sync_transaction() = 0;
-  virtual std::list<Glib::ustring> get_all_note_uuids() = 0;
+  virtual std::vector<Glib::ustring> get_all_note_uuids() = 0;
   virtual std::map<Glib::ustring, NoteUpdate> get_note_updates_since(int revision) = 0;
-  virtual void delete_notes(const std::list<Glib::ustring> & deletedNoteUUIDs) = 0;
-  virtual void upload_notes(const std::list<Note::Ptr> & notes) = 0;
+  virtual void delete_notes(const std::vector<Glib::ustring> & deletedNoteUUIDs) = 0;
+  virtual void upload_notes(const std::vector<Note::Ptr> & notes) = 0;
   virtual int latest_revision() = 0; // NOTE: Only reliable during a transaction
   virtual SyncLockInfo current_sync_lock() = 0;
   virtual Glib::ustring id() = 0;
