@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014,2017 Aurimas Cernius
+ * Copyright (C) 2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -76,9 +76,9 @@ namespace gnote {
   }
 
 
-  void Tag::get_notes(std::list<NoteBase*> & l) const
+  std::vector<NoteBase*> Tag::get_notes() const
   {
-    sharp::map_get_values(m_notes, l);
+    return sharp::map_get_values(m_notes);
   }
 
 
