@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011,2013-2014,2017 Aurimas Cernius
+ * Copyright (C) 2011,2013-2014,2017,2019 Aurimas Cernius
  * Copyright (C) 2010 Debarshi Ray
  * Copyright (C) 2009 Hubert Figuiere
  *
@@ -111,7 +111,7 @@ namespace gnote {
         return iter->second;
       }
       else {
-        Tag::Ptr t(new Tag(tag_name));
+        Tag::Ptr t(std::make_shared<Tag>(tag_name));
         m_internal_tags [ t->normalized_name() ] = t;
         return t;
       }
@@ -125,7 +125,7 @@ namespace gnote {
 
       tag = get_tag (normalized_tag_name);
       if (!tag) {
-        tag.reset(new Tag (sharp::string_trim(tag_name)));
+        tag = std::make_shared<Tag>(sharp::string_trim(tag_name));
         iter = m_tags->append ();
         (*iter)[m_columns.m_tag] = tag;
         m_tag_map [tag->normalized_name()] = iter;
@@ -208,9 +208,8 @@ namespace gnote {
         DBG_OUT("Removed TreeIter from tag_map: %s", tag->normalized_name().c_str());
         tag_removed = true;
 
-        std::list<NoteBase*> notes;
-        tag->get_notes(notes);
-        FOREACH(NoteBase *note_iter, notes) {
+        auto notes = tag->get_notes();
+        for(NoteBase *note_iter : notes) {
           note_iter->remove_tag(tag);
         }
       }
@@ -221,11 +220,13 @@ namespace gnote {
     }
   }
   
-  void TagManager::all_tags(std::list<Tag::Ptr> & tags) const
+  std::vector<Tag::Ptr> TagManager::all_tags() const
   {
+    std::vector<Tag::Ptr> tags;
+
     // Add in the system tags first
-    sharp::map_get_values(m_internal_tags, tags);
-    
+    tags = sharp::map_get_values(m_internal_tags);
+
     // Now all the other tags
     for(TagMap::const_iterator iter = m_tag_map.begin();
         iter != m_tag_map.end(); ++iter) {
@@ -233,6 +234,8 @@ namespace gnote {
       iter->second->get_value(0, tag);      
       tags.push_back(tag);
     }
+
+    return tags;
   }
 
 }
