@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014,2017 Aurimas Cernius
+ * Copyright (C) 2014,2017,2019-2020 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,22 +30,24 @@ Glib::ustring NoteManager::test_notes_dir()
 }
 
 
-NoteManager::NoteManager(const Glib::ustring & notesdir)
-  : gnote::NoteManagerBase(notesdir)
+NoteManager::NoteManager(const Glib::ustring & notesdir, gnote::IGnote & g)
+  : gnote::NoteManagerBase(g)
+  , m_notebook_manager(*this)
+  , m_note_archiver(*this)
 {
   Glib::ustring backup = notesdir + "/Backup";
-  _common_init(notesdir, backup);
+  init(notesdir, backup);
 }
 
 gnote::NoteBase::Ptr NoteManager::note_create_new(const Glib::ustring & title, const Glib::ustring & file_name)
 {
-  gnote::NoteData *note_data = new gnote::NoteData(gnote::NoteBase::url_from_path(file_name));
+  auto note_data = std::make_unique<gnote::NoteData>(gnote::NoteBase::url_from_path(file_name));
   note_data->title() = title;
-  sharp::DateTime date(sharp::DateTime::now());
+  Glib::DateTime date(Glib::DateTime::create_now_local());
   note_data->create_date() = date;
   note_data->set_change_date(date);
 
-  return Note::Ptr(new Note(note_data, file_name, *this));
+  return std::make_shared<Note>(std::move(note_data), file_name, *this);
 }
 
 gnote::NoteBase::Ptr NoteManager::note_load(const Glib::ustring & file_name)
