@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014 Aurimas Cernius
+ * Copyright (C) 2014,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,8 +17,10 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include "base/macros.hpp"
+#include "ignote.hpp"
 #include "notemanagerbase.hpp"
+#include "notebooks/notebookmanager.hpp"
+#include "test/testtagmanager.hpp"
 
 
 namespace test {
@@ -29,10 +31,31 @@ class NoteManager
 public:
   static Glib::ustring test_notes_dir();
 
-  explicit NoteManager(const Glib::ustring & notes_dir);
+  NoteManager(const Glib::ustring & notes_dir, gnote::IGnote & g);
+
+  virtual gnote::notebooks::NotebookManager & notebook_manager() override
+    {
+      return m_notebook_manager;
+    }
+  virtual gnote::NoteArchiver & note_archiver() override
+    {
+      return m_note_archiver;
+    }
+  virtual const gnote::ITagManager & tag_manager() const override
+    {
+      return m_tag_manager;
+    }
+  virtual gnote::ITagManager & tag_manager() override
+    {
+      return m_tag_manager;
+    }
 protected:
   virtual gnote::NoteBase::Ptr note_create_new(const Glib::ustring & title, const Glib::ustring & file_name) override;
   virtual gnote::NoteBase::Ptr note_load(const Glib::ustring & file_name) override;
+private:
+  gnote::notebooks::NotebookManager m_notebook_manager;
+  gnote::NoteArchiver m_note_archiver;
+  TagManager m_tag_manager;
 };
 
 }
