@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017-2018 Aurimas Cernius
+ * Copyright (C) 2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -29,9 +29,9 @@ SyncAddin::SyncAddin(const Glib::ustring & sync_path)
 {
 }
 
-gnote::sync::SyncServer::Ptr SyncAddin::create_sync_server()
+gnote::sync::SyncServer *SyncAddin::create_sync_server()
 {
-  return gnote::sync::FileSystemSyncServer::create(Gio::File::create_for_path(m_sync_path), "test");
+  return new gnote::sync::FileSystemSyncServer(Gio::File::create_for_path(m_sync_path), "test");
 }
 
 void SyncAddin::post_sync_cleanup()
@@ -43,8 +43,9 @@ Gtk::Widget *SyncAddin::create_preferences_control(EventHandler /*requiredPrefCh
   return NULL;
 }
 
-bool SyncAddin::save_configuration()
+bool SyncAddin::save_configuration(const sigc::slot<void, bool, Glib::ustring> & on_saved)
 {
+  on_saved(true, "");
   return true;
 }
 
