@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017-2018 Aurimas Cernius
+ * Copyright (C) 2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,18 +23,18 @@
 
 namespace test {
 
-SyncManager::SyncManager(gnote::NoteManagerBase & manager, const Glib::ustring & sync_path)
-  : gnote::sync::SyncManager(manager)
+SyncManager::SyncManager(gnote::IGnote & g, gnote::NoteManagerBase & manager, const Glib::ustring & sync_path)
+  : gnote::sync::SyncManager(g, manager)
   , m_sync_path(sync_path)
 {
-  m_client = gnote::sync::SyncClient::Ptr(new test::SyncClient(manager));
+  m_client.reset(new test::SyncClient(manager));
 }
 
-test::SyncClient::Ptr SyncManager::get_client(const Glib::ustring & manifest)
+test::SyncClient & SyncManager::get_client(const Glib::ustring & manifest)
 {
-  SyncClient::Ptr client = dynamic_pointer_cast<SyncClient>(m_client);
-  client->set_manifest_path(manifest);
-  client->reparse();
+  SyncClient & client = dynamic_cast<SyncClient&>(*m_client);
+  client.set_manifest_path(manifest);
+  client.reparse();
   return client;
 }
 
@@ -67,7 +67,7 @@ gnote::sync::SyncServiceAddin *SyncManager::get_configured_sync_service()
   return get_sync_service_addin("");
 }
 
-void SyncManager::delete_notes_in_main_thread(const gnote::sync::SyncServer::Ptr & server)
+void SyncManager::delete_notes_in_main_thread(gnote::sync::SyncServer & server)
 {
   delete_notes(server);
 }
