@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017-2018 Aurimas Cernius
+ * Copyright (C) 2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #ifndef _TEST_TESTSYNCMANAGER_HPP_
 #define _TEST_TESTSYNCMANAGER_HPP_
 
-#include "base/macros.hpp"
 #include "synchronization/syncmanager.hpp"
 #include "testsyncclient.hpp"
 
@@ -32,16 +31,16 @@ class SyncManager
   : public gnote::sync::SyncManager
 {
 public:
-  SyncManager(gnote::NoteManagerBase & note_manager, const Glib::ustring & sync_path);
+  SyncManager(gnote::IGnote & g, gnote::NoteManagerBase & note_manager, const Glib::ustring & sync_path);
   virtual void reset_client() override;
   virtual void perform_synchronization(const gnote::sync::SyncUI::Ptr & sync_ui) override;
   virtual void resolve_conflict(gnote::sync::SyncTitleConflictResolution resolution) override;
   virtual bool synchronized_note_xml_matches(const Glib::ustring & noteXml1, const Glib::ustring & noteXml2) override;
   virtual gnote::sync::SyncServiceAddin *get_sync_service_addin(const Glib::ustring & sync_service_id) override;
   virtual gnote::sync::SyncServiceAddin *get_configured_sync_service() override;
-  virtual void delete_notes_in_main_thread(const gnote::sync::SyncServer::Ptr & server) override;
+  virtual void delete_notes_in_main_thread(gnote::sync::SyncServer & server) override;
   virtual void note_save(const gnote::Note::Ptr & note) override;
-  test::SyncClient::Ptr get_client(const Glib::ustring & manifest);
+  test::SyncClient & get_client(const Glib::ustring & manifest);
 protected:
   virtual void create_note_in_main_thread(const gnote::sync::NoteUpdate & noteUpdate) override;
   virtual void update_note_in_main_thread(const gnote::Note::Ptr & existingNote, const gnote::sync::NoteUpdate & noteUpdate) override;
