@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2014,2017-2018 Aurimas Cernius
+ * Copyright (C) 2014,2017-2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,17 +22,6 @@
 
 namespace test {
 
-TagManager *TagManager::s_manager = NULL;
-
-void TagManager::ensure_exists()
-{
-  // existing tag manager can be invalid, recreate it for new test
-  if(s_manager != NULL) {
-    delete s_manager;
-  }
-  s_manager = new TagManager;
-}
-
 gnote::Tag::Ptr TagManager::get_tag(const Glib::ustring & tag_name) const
 {
   auto iter = m_tags.find(tag_name);
@@ -73,9 +62,9 @@ void TagManager::remove_tag(const gnote::Tag::Ptr & tag)
   }
 }
 
-void TagManager::all_tags(std::list<gnote::Tag::Ptr> & list) const
+std::vector<gnote::Tag::Ptr> TagManager::all_tags() const
 {
-  list.clear();
+  std::vector<gnote::Tag::Ptr> list;
   for(auto iter = m_tags.begin(); iter != m_tags.end(); ++iter) {
     list.push_back(iter->second);
   }
