@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2017 Aurimas Cernius
+ * Copyright (C) 2017,2019 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,8 +20,8 @@
 
 #include <UnitTest++/UnitTest++.h>
 
+#include "test/testgnote.hpp"
 #include "test/testnotemanager.hpp"
-#include "test/testtagmanager.hpp"
 
 
 SUITE(NoteManager)
@@ -32,8 +32,9 @@ SUITE(NoteManager)
     char *notes_dir = g_mkdtemp(notes_dir_tmpl);
     CHECK(notes_dir != NULL);
 
-    new test::TagManager;
-    test::NoteManager manager(notes_dir);
+    test::Gnote g;
+    test::NoteManager manager(notes_dir, g);
+    g.notebook_manager(&manager.notebook_manager());
     manager.create();
     manager.create();
     gnote::NoteBase::Ptr test_note = manager.create("test note");
