@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2011-2013,2015-2017 Aurimas Cernius
+ * Copyright (C) 2011-2013,2015-2017,2019-2020 Aurimas Cernius
  * Copyright (C) 2009 Hubert Figuiere
  *
  * This program is free software: you can redistribute it and/or modify
@@ -38,15 +38,15 @@
 #include <gtkmm/toggletoolbutton.h>
 #include <gtkmm/toolbar.h>
 
-#include "base/macros.hpp"
 #include "sharp/exception.hpp"
 #include "sharp/uri.hpp"
 
-namespace sharp {
-  class DateTime;
-}
 
 namespace gnote {
+
+class Preferences;
+
+
   namespace utils {
 
     void popup_menu(Gtk::Menu &menu, const GdkEventButton *);
@@ -56,35 +56,25 @@ namespace gnote {
     void show_opening_location_error(Gtk::Window * parent,
                                      const Glib::ustring & url,
                                      const Glib::ustring & error);
-    Glib::ustring get_pretty_print_date(const sharp::DateTime &, bool show_time);
-    Glib::ustring get_pretty_print_date(const sharp::DateTime &, bool show_time, bool use_12h);
+    Glib::ustring get_pretty_print_date(const Glib::DateTime &, bool show_time, Preferences & preferences);
+    Glib::ustring get_pretty_print_date(const Glib::DateTime &, bool show_time, bool use_12h);
 
     void main_context_invoke(const sigc::slot<void> & slot);
     void main_context_call(const sigc::slot<void> & slot);
 
-    Gtk::Widget * create_popover_button(const Glib::ustring & action, const Glib::ustring & label);
-    Gtk::Widget * create_popover_submenu_button(const Glib::ustring & submenu, const Glib::ustring & label);
-    Gtk::Box * create_popover_submenu(const Glib::ustring & name);
-    void set_common_popover_widget_props(Gtk::Widget & widget);
-    void set_common_popover_widget_props(Gtk::Box & widget);
-
-    void add_item_to_ordered_map(std::map<int, Gtk::Widget*> & dest, int order, Gtk::Widget *item);
-    void merge_ordered_maps(std::map<int, Gtk::Widget*> & dest, const std::map<int, Gtk::Widget*> & adds);
-
-    class PopoverSubmenu
+    template <typename T>
+    bool remove_swap_back(std::vector<T> & v, const T & e)
     {
-    public:
-      PopoverSubmenu(const Glib::ustring & name)
-        : m_name(name)
-      {}
-
-      const Glib::ustring & name() const
-        {
-          return m_name;
+      for(typename std::vector<T>::iterator iter = v.begin(); iter != v.end(); ++iter) {
+        if(*iter == e) {
+          *iter = v.back();
+          v.pop_back();
+          return true;
         }
-    private:
-      const Glib::ustring m_name;
-    };
+      }
+
+      return false;
+    }
 
     class GlobalKeybinder
     {
@@ -137,14 +127,14 @@ namespace gnote {
 
 
     class UriList
-      : public std::list<sharp::Uri>
+      : public std::vector<sharp::Uri>
     {
     public:
 //      UriList(const NoteList & notes);
       UriList(const Glib::ustring & data);
       UriList(const Gtk::SelectionData & selection);
       Glib::ustring to_string() const;
-      void get_local_paths(std::list<Glib::ustring> &) const;
+      std::vector<Glib::ustring> get_local_paths() const;
       
     private:
       void load_from_string(const Glib::ustring & data);
@@ -230,7 +220,7 @@ namespace gnote {
       void cancel();
       sigc::signal<void> signal_timeout;
     private:
-      static bool callback(InterruptableTimeout*);
+      static int callback(InterruptableTimeout*);
       bool timeout_expired();
       guint m_timeout_id;
     };
