@@ -31,12 +31,12 @@
 #include "sharp/string.hpp"
 #include "debug.hpp"
 #include "iactionmanager.hpp"
+#include "ignote.hpp"
 #include "mainwindow.hpp"
 #include "noteeditor.hpp"
 #include "notemanager.hpp"
 #include "notewindow.hpp"
 #include "preferences.hpp"
-#include "itagmanager.hpp"
 #include "triehit.hpp"
 #include "watchers.hpp"
 
@@ -280,7 +280,7 @@ namespace gnote {
   }
 
 
-#if FIXED_GTKSPELL
+#if ENABLE_GSPELL
   const char *NoteSpellChecker::LANG_PREFIX = "spellchecklang:";
   const char *NoteSpellChecker::LANG_DISABLED = "disabled";
 
@@ -291,7 +291,7 @@ namespace gnote {
 
   void NoteSpellChecker::on_note_opened ()
   {
-    Glib::RefPtr<Gio::Settings> settings = Preferences::obj()
+    Glib::RefPtr<Gio::Settings> settings = ignote().preferences()
       .get_schema_settings(Preferences::SCHEMA_GNOTE);
     settings->signal_changed()
       .connect(sigc::mem_fun(*this, &NoteSpellChecker::on_enable_spellcheck_changed));
@@ -341,12 +341,15 @@ namespace gnote {
     Glib::ustring lang = get_language();
 
     if (!m_obj_ptr && lang != LANG_DISABLED) {
-      m_obj_ptr = gtk_spell_checker_new();
-      if(lang != "") {
-        gtk_spell_checker_set_language(m_obj_ptr, lang.c_str(), NULL);
-      }
-      g_signal_connect(G_OBJECT(m_obj_ptr), "language-changed", G_CALLBACK(language_changed), this);
-      gtk_spell_checker_attach(m_obj_ptr, get_window()->editor()->gobj());
+      const GspellLanguage *language = gspell_language_lookup(lang.c_str());
+      m_obj_ptr = gspell_checker_new(language);
+      g_signal_connect(G_OBJECT(m_obj_ptr), "notify::language", G_CALLBACK(language_changed), this);
+      Glib::RefPtr<Gtk::TextBuffer> buffer = get_window()->editor()->get_buffer();
+      GspellTextBuffer *gspell_buffer = gspell_text_buffer_get_from_gtk_text_buffer (buffer->gobj());
+      gspell_text_buffer_set_spell_checker (gspell_buffer, m_obj_ptr);
+      GspellTextView *gspell_view = gspell_text_view_get_from_gtk_text_view (get_window()->editor()->gobj());
+      gspell_text_view_set_inline_spell_checking (gspell_view, TRUE);
+      gspell_text_view_set_enable_language_menu (gspell_view, TRUE);
       m_enabled = true;
     }
     else {
@@ -368,7 +371,9 @@ namespace gnote {
     m_tag_applied_cid.disconnect();
     
     if(m_obj_ptr) {
-      gtk_spell_checker_detach(m_obj_ptr);
+      Glib::RefPtr<Gtk::TextBuffer> buffer = get_window()->editor()->get_buffer();
+      GspellTextBuffer *gspell_buffer = gspell_text_buffer_get_from_gtk_text_buffer (buffer->gobj());
+      gspell_text_buffer_set_spell_checker (gspell_buffer, NULL);
       m_obj_ptr = NULL;
     }
   }
@@ -379,8 +384,7 @@ namespace gnote {
     if (key != Preferences::ENABLE_SPELLCHECKING) {
       return;
     }
-    bool value = Preferences::obj()
-      .get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(key);
+    bool value = ignote().preferences().get_schema_settings(Preferences::SCHEMA_GNOTE)->get_boolean(key);
     
     if (value) {
       attach ();
@@ -422,9 +426,10 @@ namespace gnote {
     }
   }
 
-  void NoteSpellChecker::language_changed(GtkSpellChecker*, gchar *lang, NoteSpellChecker *checker)
+  void NoteSpellChecker::language_changed(GspellChecker* self, GParamSpec*, NoteSpellChecker *checker)
   {
     try {
+      const gchar *lang = gspell_language_get_code (gspell_checker_get_language (self));
       checker->on_language_changed(lang);
     }
     catch(...) {
@@ -439,7 +444,7 @@ namespace gnote {
     if(tag && tag->name() != tag_name) {
       get_note()->remove_tag(tag);
     }
-    tag = ITagManager::obj().get_or_create_tag(tag_name);
+    tag = manager().tag_manager().get_or_create_tag(tag_name);
     get_note()->add_tag(tag);
     DBG_OUT("Added language tag %s", tag_name.c_str());
   }
@@ -483,7 +488,7 @@ namespace gnote {
     else {
       Glib::ustring tag_name = LANG_PREFIX;
       tag_name += LANG_DISABLED;
-      tag = ITagManager::obj().get_or_create_tag(tag_name);
+      tag = manager().tag_manager().get_or_create_tag(tag_name);
       get_note()->add_tag(tag);
       detach_checker();
     }
@@ -1047,7 +1052,7 @@ namespace gnote {
     // also works around the bug.
     if (link) {
       DBG_OUT ("Opening note '%s' on click...", link_name.c_str());
-      MainWindow::present_default(std::static_pointer_cast<Note>(link));
+      MainWindow::present_default(ignote(), std::static_pointer_cast<Note>(link));
       return true;
     }
 
@@ -1373,10 +1378,10 @@ namespace gnote {
 
   void NoteTagsWatcher::on_tag_removed(const NoteBase::Ptr&, const Glib::ustring& tag_name)
   {
-    Tag::Ptr tag = ITagManager::obj().get_tag(tag_name);
+    Tag::Ptr tag = manager().tag_manager().get_tag(tag_name);
     DBG_OUT ("Watchers.OnTagRemoved popularity count: %d", tag ? tag->popularity() : 0);
     if (tag && tag->popularity() == 0) {
-      ITagManager::obj().remove_tag(tag);
+      manager().tag_manager().remove_tag(tag);
     }
   }
 
